@@ -23,6 +23,8 @@
 #include "skgunitvalueobject.h"
 #include "skgdocumentbank.h"
 #include "skgtraces.h"
+
+#include <QRegExp>
 #include <math.h>
 
 SKGUnitObject::SKGUnitObject(const SKGDocument* iDocument, int iID)
@@ -80,6 +82,7 @@ QString SKGUnitObject::getWhereclauseId() const
 
         return output;
 }
+
 QStringList SKGUnitObject::getListofKnownCurrencies()
 {
         QStringList output;
@@ -91,7 +94,8 @@ QStringList SKGUnitObject::getListofKnownCurrencies()
         << tr("Deutsche mark (DEM)")
         << tr("Espana Peseta (ESP)")
         << tr("Italian Lira (ITL)")
-        << tr("Pound sterling (UK)")
+        << tr("Pound sterling (GBP)")
+        << tr("Canadian dollar (CAD)")
         << tr("CAC 40")
         << tr("Dow Jones (DJIA)")
         << tr("NASDAQ")
@@ -100,6 +104,16 @@ QStringList SKGUnitObject::getListofKnownCurrencies()
         return output;
 }
 
+QString SKGUnitObject::getInternationalCode(const QString& iUnitName)
+{
+        QString output;
+        QRegExp rx(".*\\((.+)\\).*");
+        if (rx.indexIn(iUnitName)!=-1) {
+                output=rx.cap(1);
+        }
+
+        return output;
+}
 SKGError SKGUnitObject::createCurrencyUnit(const SKGDocumentBank* iDocument, const QString& iUnitName, SKGUnitObject& oUnit)
 {
         SKGError err;
@@ -117,6 +131,7 @@ SKGError SKGUnitObject::createCurrencyUnit(const SKGDocumentBank* iDocument, con
                 QString prim=((SKGDocumentBank*) iDocument)->getPrimaryUnit();
                 QString seco=((SKGDocumentBank*) iDocument)->getSecondaryUnit();
 
+                //Principal units
                 if (iUnitName==tr("Euro (EUR)") || iUnitName=="EUR" || iUnitName==QString::fromUtf8("€")) {
                         //Euro
                         name=tr("Euro (EUR)");
@@ -125,15 +140,33 @@ SKGError SKGUnitObject::createCurrencyUnit(const SKGDocumentBank* iDocument, con
                         date=QDate(2002,1,1);
                         value=1;
                         type=(prim.isEmpty() || prim==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
-                        if (prim==QString::fromUtf8("$")) {
-                                internet="EURUSD=X";
-                                value=-1;
-
-                                parentUnit=SKGUnitObject(iDocument);
-                                err=parentUnit.setSymbol(QString::fromUtf8("$"));
-                                if (err.isSucceeded()) err=parentUnit.load();
-                        }
-                } else if (iUnitName==tr("French Franc (FRF)") || iUnitName=="FRF" || iUnitName=="F") {
+                } else if (iUnitName==tr("United States Dollar (USD)") || iUnitName=="USD" || iUnitName==QString::fromUtf8("$")) {
+                        //US Dollar
+                        name=tr("United States dollar (USD)");
+                        symbol=QString::fromUtf8("$");
+                        country=tr("United States");
+                        date=QDate(1959,1,1);
+                        value=1;
+                        type=(prim.isEmpty() || prim==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
+                } else if (iUnitName==tr("Canadian dollar (CAD)") || iUnitName=="CAD" || iUnitName==QString::fromUtf8("C$")) {
+                        //US Dollar
+                        name=tr("Canadian dollar (CAD)");
+                        symbol=QString::fromUtf8("C$");
+                        country=tr("Canada");
+                        date=QDate(1858,1,1);
+                        value=1;
+                        type=(prim.isEmpty() || prim==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
+                } else if (iUnitName==tr("Pound sterling (GBP)") || iUnitName=="GBP" || iUnitName==QString::fromUtf8("£")) {
+                        //Lyre
+                        name=tr("Pound sterling (GBP)");
+                        symbol=QString::fromUtf8("£");
+                        country=tr("United Kingdom");
+                        date=QDate(1990,9,8);
+                        value=1;
+                        type=(prim.isEmpty() || prim==symbol  ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
+                }
+                //Europeen units
+                else if (iUnitName==tr("French Franc (FRF)") || iUnitName=="FRF" || iUnitName=="F") {
                         //Franc
                         name=tr("French Franc (FRF)");
                         symbol="F";
@@ -183,39 +216,9 @@ SKGError SKGUnitObject::createCurrencyUnit(const SKGDocumentBank* iDocument, con
                         type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
 
                         err=SKGUnitObject::createCurrencyUnit(iDocument, "EUR", parentUnit);
-                } else if (iUnitName==tr("Pound sterling (UK)") || iUnitName=="GBP" || iUnitName==QString::fromUtf8("£")) {
-                        //Lyre
-                        name=tr("Pound sterling (UK)");
-                        symbol=QString::fromUtf8("£");
-                        country=tr("United Kingdom");
-                        date=QDate(1990,9,8);
-                        value=1;
-                        type=(seco.isEmpty() || seco==symbol  ? SKGUnitObject::SECONDARY : SKGUnitObject::CURRENCY);
-                        if (prim==QString::fromUtf8("€")) {
-                                internet="GBPUSD=X /";
-                                value=-1;
-
-                                parentUnit=SKGUnitObject(iDocument);
-                                err=parentUnit.setSymbol(QString::fromUtf8("€"));
-                                if (err.isSucceeded()) err=parentUnit.load();
-                        }
-                } else if (iUnitName==tr("United States Dollar (USD)") || iUnitName=="USD" || iUnitName==QString::fromUtf8("$")) {
-                        //US Dollar
-                        name=tr("United States dollar (USD)");
-                        symbol=QString::fromUtf8("$");
-                        country=tr("United States");
-                        date=QDate(1959,1,1);
-                        value=1;
-                        type=(prim.isEmpty() || prim==symbol ? SKGUnitObject::PRIMARY : SKGUnitObject::CURRENCY);
-                        if (prim==QString::fromUtf8("€")) {
-                                internet="EURUSD=X /";
-                                value=-1;
-
-                                parentUnit=SKGUnitObject(iDocument);
-                                err=parentUnit.setSymbol(QString::fromUtf8("€"));
-                                if (err.isSucceeded()) err=parentUnit.load();
-                        }
-                } else if (iUnitName==tr("CAC 40")) {
+                }
+                //Indexes
+                else if (iUnitName==tr("CAC 40")) {
                         //US Dollar
                         name=iUnitName;
                         symbol=iUnitName;
@@ -251,10 +254,27 @@ SKGError SKGUnitObject::createCurrencyUnit(const SKGDocumentBank* iDocument, con
                         value=-1;
                         internet="^SBF120";
                         type=SKGUnitObject::INDEX;
+                } else err=SKGError(ERR_INVALIDARG, tr("Unknown unit [%1]").arg(iUnitName));
+
+                //Point on primary unit
+                if (value==1 && err.isSucceeded() && (type==SKGUnitObject::CURRENCY || type==SKGUnitObject::SECONDARY)) {
+                        SKGUnitObject primunit(iDocument);
+                        err=primunit.setSymbol(prim);
+                        if (err.isSucceeded()) err=primunit.load();
+                        if (err.isSucceeded()) {
+                                QString codeprimunit=getInternationalCode(primunit.getName());
+                                QString codeunit=getInternationalCode(name);
+                                if (!codeprimunit.isEmpty()) {
+                                        internet=codeunit+codeprimunit+"=X";
+                                        value=-1;
+
+                                        parentUnit=SKGUnitObject(iDocument);
+                                        err=parentUnit.setSymbol(prim);
+                                        if (err.isSucceeded()) err=parentUnit.load();
+                                }
+                        }
+
                 }
-
-
-                else err=SKGError(ERR_INVALIDARG, tr("Unknown unit [%1]").arg(iUnitName));
                 //TODO: other european currencies. see http://fr.wikipedia.org/wiki/Euro#Conversion_de_l.E2.80.99euro_dans_les_anciennes_devises_des_pays_membres
 
                 if (err.isSucceeded()) err = oUnit.setName(name);
