@@ -134,10 +134,7 @@ void SKGCalculatorEdit::keyPressEvent(int key)
                                 if (t.length()>0 && t[0]=='+' && result.toNumber()>0) res='+';
                                 res+=result.toString();
                                 setText(res);
-                        } else {
-                                //TODO: display error
                         }
-
                 }
         }
 }
