@@ -147,6 +147,11 @@ public slots:
          */
         virtual void onSwitchToolBarVisibility();
 
+        /**
+         * Swith antialiasing
+         */
+        virtual void onSwitchAntialiasing();
+
 private slots:
         void showMenu(const QPoint& pos);
 
@@ -156,8 +161,9 @@ private:
 
         QMatrix originalMatrix;
 
-        KMenu* menu;
+        KMenu* mainMenu;
         QAction* actShowToolBar;
+        QAction* actAntialiasing;
 };
 
 #endif // SKGGRAPHICSVIEW_H
