@@ -60,7 +60,7 @@ public:
          * @param iDocument the document to manage data
          * @param iArguments the arguments
          */
-        SKGMainPanel(KSplashScreen* iSplashScreen, SKGDocument* iDocument, const QStringList& iArguments);
+        SKGMainPanel ( KSplashScreen* iSplashScreen, SKGDocument* iDocument, const QStringList& iArguments );
 
         /**
          * Default Destructor
@@ -96,14 +96,14 @@ public:
          * @param iIndex the index of the plugin
          * @return the plugin pointer. Can be NULL. Mustn't be deleted
          */
-        virtual SKGInterfacePlugin * getPluginByIndex(int iIndex);
+        virtual SKGInterfacePlugin * getPluginByIndex ( int iIndex );
 
         /**
          * Return the plugin number by name
          * @param iName the name of the plugin
          * @return the plugin pointer. Can be NULL. Mustn't be deleted
          */
-        virtual SKGInterfacePlugin * getPluginByName(const QString& iName);
+        virtual SKGInterfacePlugin * getPluginByName ( const QString& iName );
 
         /**
          * Get the index of the current tab
@@ -118,10 +118,10 @@ public:
         virtual SKGTabWidget* currentTab() const;
 
         /**
-         * Get then context list
-         * @return the list
+         * Get the label for normal message in status bar
+         * @return the label
          */
-        virtual KListWidget* contextList() const;
+        virtual QLabel* statusNormalMessage() const;
 
         /**
          * Get the current splash screen. NULL is the splash screen is closed.
@@ -139,7 +139,7 @@ public:
          * Set the current page
          * @param iIndex the current page
          */
-        virtual void setCurrentTabIndex(int iIndex);
+        virtual void setCurrentTabIndex ( int iIndex );
 
         /**
          * Open a plugin in a page
@@ -149,21 +149,21 @@ public:
          * @param title title of the page
          * @return the opened tab
          */
-        virtual SKGTabWidget* setNewTabContent(SKGInterfacePlugin* plugin, int index=-1, const QString& parameters="", const QString& title="");
+        virtual SKGTabWidget* setNewTabContent ( SKGInterfacePlugin* plugin, int index=-1, const QString& parameters="", const QString& title="" );
 
         /**
          * Register a global action
          * @param iIdentifier identifier of the action
          * @param iAction action pointer
          */
-        virtual void registedGlobalAction(const QString& iIdentifier, KAction* iAction);
+        virtual void registedGlobalAction ( const QString& iIdentifier, KAction* iAction );
 
         /**
          * Get a registered global action
          * @param iIdentifier identifier of the action
          * @return action pointer
          */
-        virtual KAction* getGlobalAction(const QString& iIdentifier);
+        virtual KAction* getGlobalAction ( const QString& iIdentifier );
 
         /**
          * Creates a modal file dialog and returns the selected filename or an empty string if none was chosen.
@@ -178,13 +178,13 @@ public:
          * @param caption the name of the dialog widget.
          * @return the file name
          */
-        static QString getSaveFileName(const KUrl & startDir = KUrl(), const QString & filter = QString(), QWidget * parent = 0, const QString & caption = QString());
+        static QString getSaveFileName ( const KUrl & startDir = KUrl(), const QString & filter = QString(), QWidget * parent = 0, const QString & caption = QString() );
 
         /**
          * Display an error message
          * @param iError the error
          */
-        static void displayErrorMessage(const SKGError& iError);
+        static void displayErrorMessage ( const SKGError& iError );
 
         /**
          * Fill a combobox with distinct values
@@ -194,12 +194,12 @@ public:
          * @param iAttribut attribute
          * @param iWhereClause where clause
          */
-        static void fillComboWithDistinctValue(
+        static void fillComboWithDistinctValue (
                 KComboBox* iComboBox,
                 const SKGDocument* iDoc,
                 const QString& iTable,
                 const QString& iAttribut,
-                const QString& iWhereClause);
+                const QString& iWhereClause );
 
 
 public slots:
@@ -212,19 +212,19 @@ public slots:
          * Send notifications corresponding to the transaction.
          * @param iTransaction the transaction identifier
          */
-        virtual void notify(int iTransaction);
+        virtual void notify ( int iTransaction );
 
         /**
          * Close a page
          * @param iWidget the page to remove (NULL means current one)
          */
-        virtual void closeTab(QWidget* iWidget=NULL);
+        virtual void closeTab ( QWidget* iWidget=NULL );
 
         /**
          * Close all other pages
          * @param iWidget the page to keep (NULL means current one)
          */
-        virtual void closeAllOtherTabs(QWidget* iWidget=NULL);
+        virtual void closeAllOtherTabs ( QWidget* iWidget=NULL );
 
         /**
          * Close all pages
@@ -236,23 +236,28 @@ protected:
          * event
          * @param e event
          */
-        virtual void changeEvent(QEvent * e );
+        virtual void changeEvent ( QEvent * e );
 
 private slots:
         void optionsPreferences();
         void onSettingsChanged();
         void onCancelCurrentAction();
+        void onQuitAction();
 
         void addTab();
-        void setTabContentFromList(QListWidgetItem* item);
+        void onBeforeOpenContext();
+        void onOpenContext();
         void onTipOfDay();
-        void onTrayActivated(QSystemTrayIcon::ActivationReason reason);
-        void onChangeStyleSheet(const QString& iNewStryle);
+        void onTrayActivated ( QSystemTrayIcon::ActivationReason reason );
+        void onChangeStyleSheet ( const QString& iNewStryle );
+        void saveDefaultState();
 private:
-        Q_DISABLE_COPY(SKGMainPanel);
+        Q_DISABLE_COPY ( SKGMainPanel );
         void setupActions();
         bool iconInSystemtray();
-        static int progressBarCallBack(int iPos, void* iProgressBar);
+        bool eventFilter ( QObject *object, QEvent *event );
+
+        static int progressBarCallBack ( int iPos, void* iProgressBar );
 
         Ui::skgmainpanel_base ui;
         Ui::skgmainpanel_pref uipref;
@@ -270,10 +275,12 @@ private:
         KAction *closePageAction;
         KAction *closeAllPagesAction;
         KAction *closeAllOtherPagesAction;
+        KAction *saveDefaultStateAction;
         KTipDatabase* tipDatabase;
         static bool currentActionCanceled;
         KPushButton *kCancelButton;
         KSystemTrayIcon* kSystemTrayIcon;
+        QLabel* kNormalMessage;
 
         struct doublePointer {
                 void* p1;
@@ -282,6 +289,7 @@ private:
 
         doublePointer progressObjects;
         QString defaultStyle;
+        bool middleClick;
 };
 
 #endif // SKGMAINPANEL_H
