@@ -40,15 +40,17 @@ SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
                                        const QString& iTable,
                                        const QString& iWhereClause,
                                        QObject *parent,
-                                       const QString& iWhereClauseChild,
+                                       const QString& iParentAttribute,
                                        bool iResetOnCreation)
                 : QAbstractItemModel(parent), isResetRealyNeeded(iResetOnCreation), document(iDocument),
                 whereClause(iWhereClause),
-                whereClauseChild(iWhereClauseChild)
+                parentAttribute(iParentAttribute)
 {
         SKGTRACEIN(1, "SKGObjectModelBase::SKGObjectModelBase");
 
         listSupportedDefault 	<< "t_name"
+        << "t_value"
+        << "d_lastmodifdate"
         << "d_date"
         << "t_savestep"
         ;
@@ -62,6 +64,16 @@ SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
         def.schema="";
         listSchema.push_back(def);
 
+        //Build schemas
+        if (getRealTable()=="parameters") {
+                SKGModelTemplate minimun;
+                minimun.id="minimun";
+                minimun.name=tr("Minimun");
+                minimun.icon="";
+                minimun.schema="t_name;t_value";
+                listSchema.push_back(minimun);
+        }
+
         connect((const QObject*) document, SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)));
         refresh();
 }
@@ -86,16 +98,7 @@ void SKGObjectModelBase::clear()
                 }
         }
 
-        QHashIterator<int, SKGObjectBase::SKGListSKGObjectBase*> i2(parentChildRelations);
-        while (i2.hasNext()) {
-                i2.next();
-                SKGObjectBase::SKGListSKGObjectBase* val=i2.value();
-                if (val) {
-                        delete val;
-                        val=NULL;
-                }
-        }
-
+        listObjects.clear();
         parentChildRelations.clear();
         childParentRelations.clear();
         objectsHashTable.clear();
@@ -104,6 +107,7 @@ void SKGObjectModelBase::clear()
 
 int SKGObjectModelBase::getID(const SKGObjectBase* obj, int row) const
 {
+        if (!parentAttribute.isEmpty()) return (obj ? obj->getID() : 0);
         return (obj ? 100*(obj->getID())+row : 0);
 }
 
@@ -129,7 +133,7 @@ void SKGObjectModelBase::setSupportedAttributes ( const QStringList & iListAttri
         } else {
                 int nb=iListAttribute.count();
                 for (int i=0; i<nb; ++i) {
-                        QStringList values = iListAttribute.at(i).split("|");
+                        QStringList values = iListAttribute.at(i).split('|');
                         int nbValues=values.count();
 
                         if (nbValues>0) {
@@ -188,6 +192,7 @@ void SKGObjectModelBase::refresh()
 {
         if (!isResetRealyNeeded) return;
         SKGTRACEIN(1, "SKGObjectModelBase::refresh");
+        emit beforeReset();
         {
                 _SKGTRACEIN(10, "QAbstractItemModel::refresh-remove");
                 clear();
@@ -197,7 +202,6 @@ void SKGObjectModelBase::refresh()
                 endRemoveRows();*/
         }
 
-        SKGObjectBase::SKGListSKGObjectBase* listObjects=NULL;
         {
                 _SKGTRACEIN(10, "QAbstractItemModel::refresh-fill");
                 QStringList listAttibutesTmp;
@@ -242,65 +246,35 @@ void SKGObjectModelBase::refresh()
                         }
 
                         //Get objects
-                        listObjects=new SKGObjectBase::SKGListSKGObjectBase();
-                        if (listObjects) {
-                                SKGObjectBase::getObjects(document, table, whereClause, *listObjects);
-                                parentChildRelations.insert(0, listObjects);
+                        SKGObjectBase::getObjects(document, table, whereClause, listObjects);
 
-                                QList<SKGObjectBase*> listObjectToTreat;
-                                QList<int> listObjectToTreatId;
+                        QList<SKGObjectBase*> listObjectToTreat;
+                        QList<int> listObjectToTreatId;
 
-                                //Initialize object to treat
-                                int nb=listObjects->count();
-                                SKGTRACEL(1) << nb << " objects found" << endl;
-                                for (int t=0; t<nb; ++t) {
-                                        SKGObjectBase* c=new SKGObjectBase(listObjects->at(t));
-                                        int id=getID(c, t);
+                        //Initialize object to treat
+                        int nb=listObjects.count();
+                        SKGTRACEL(1) << nb << " objects found" << endl;
+                        for (int t=0; t<nb; ++t) {
+                                SKGObjectBase* c=new SKGObjectBase(listObjects.at(t));
+                                int id=getID(c, t);
 
-                                        listObjectToTreat.push_back(c);
-                                        listObjectToTreatId.push_back(id);
-
-                                        childParentRelations.insert(id, 0);
-                                        objectsHashTableRows.insert(id, t);
-                                        objectsHashTable.insert(id, c);
+                                int idparent=0;
+                                if (!parentAttribute.isEmpty()) {
+                                        int idp=SKGServices::stringToInt(c->getAttribute(parentAttribute));
+                                        if (idp>0) idparent=idp;
                                 }
 
-                                //Build tree if needed
-                                if (!whereClauseChild.isEmpty()) {
-                                        //For each object, we have to create hash tables to find children from parent and parent for a child
-                                        for (int i=0; i<listObjectToTreat.count(); ++i) { //WARNING: the list is modified during treatement
-                                                //Get parent
-                                                SKGObjectBase* parent=listObjectToTreat.at(i);
-                                                if (parent) {
-                                                        int parentid=listObjectToTreatId.at(i);
+                                listObjectToTreat.push_back(c);
+                                listObjectToTreatId.push_back(id);
 
-                                                        //Get children
-                                                        SKGObjectBase::SKGListSKGObjectBase children;
-                                                        QString wc=whereClauseChild;
-                                                        wc.replace("#ID#", SKGServices::intToString(parent->getID()));
-                                                        SKGObjectBase::SKGListSKGObjectBase* listObjectsChildren=new SKGObjectBase::SKGListSKGObjectBase();
-                                                        if (listObjectsChildren) {
-                                                                SKGObjectBase::getObjects(document, table, wc, *listObjectsChildren);
+                                childParentRelations.insert(id, idparent);
 
-                                                                //Addition relationship in hash table
-                                                                parentChildRelations.insert(parentid, listObjectsChildren);
-                                                                int nbc=listObjectsChildren->count();
-                                                                for (int k=0; k<nbc; ++k) {
-                                                                        //Addition children in list to treat
-                                                                        SKGObjectBase* c=new SKGObjectBase(listObjectsChildren->at(k));
-                                                                        int childId=getID(c, k);
+                                QList<int> childrensids=parentChildRelations.value(idparent);
+                                childrensids.push_back(id);
 
-                                                                        listObjectToTreat.push_back(c);
-                                                                        listObjectToTreatId.push_back(childId);
-
-                                                                        childParentRelations.insert(childId, parentid);
-                                                                        objectsHashTableRows.insert(childId, k);
-                                                                        objectsHashTable.insert(childId, c);
-                                                                }
-                                                        }
-                                                }
-                                        }
-                                }
+                                parentChildRelations.insert(idparent, childrensids);
+                                objectsHashTableRows.insert(id, t);
+                                objectsHashTable.insert(id, c);
                         }
                 }
 
@@ -312,6 +286,7 @@ void SKGObjectModelBase::refresh()
                         QAbstractItemModel::reset();
                 }
         }
+        emit afterReset();
 }
 
 int SKGObjectModelBase::rowCount(const QModelIndex &parent ) const
@@ -322,9 +297,9 @@ int SKGObjectModelBase::rowCount(const QModelIndex &parent ) const
         int idParent=0;
         if (parent.isValid()) idParent = parent.internalId();
 
-        SKGObjectBase::SKGListSKGObjectBase* children=parentChildRelations.value(idParent);
+        QList<int> children=parentChildRelations.value(idParent);
         //SKGTRACE << table << "-rowCount(" << idParent << " )=" << (children ? children->count() : 0) << endl;
-        return (children ? children->count() : 0);
+        return children.count();
 
 }
 
@@ -342,11 +317,8 @@ QModelIndex SKGObjectModelBase::index ( int row, int column, const QModelIndex &
         int idParent=0;
         if (parent.isValid())  idParent = parent.internalId();
 
-        SKGObjectBase* child=NULL;
-        SKGObjectBase::SKGListSKGObjectBase* children=parentChildRelations.value(idParent);
-        if (children)  child=(SKGObjectBase*) &(children->at(row));
+        int idChild=parentChildRelations.value(idParent).at(row);
 
-        int idChild=getID(child, row);
         //SKGTRACE << table << "-" << idParent << "(" << row << ") ==> " << idChild << endl;
         return createIndex(row, column, idChild);
 }
@@ -404,7 +376,7 @@ QVariant SKGObjectModelBase::headerData ( int section, Qt::Orientation orientati
 
                         if (section>=0 && section< listVisibility.count()) {
                                 att+=QString("|")+(listVisibility[section] ? "Y" : "N");
-                                if (section>=0 && section< listSize.count()) att+="|"+SKGServices::intToString(listSize.at(section));
+                                if (section>=0 && section< listSize.count()) att+='|'+SKGServices::intToString(listSize.at(section));
                         }
                         return att;
                 }
@@ -534,6 +506,12 @@ QVariant SKGObjectModelBase::data(const QModelIndex &index, int role) const
                                 if (shortDate!=fancyDate) return shortDate;
                         }
                 }
+                IFSKGTRACEL(1) {
+                        SKGObjectBase* obj = getObjectPointer(index);
+                        if (obj) {
+                                return obj->getUniqueID();
+                        }
+                }
                 break;
         }
         default : {}
@@ -549,8 +527,7 @@ Qt::ItemFlags SKGObjectModelBase::flags(const QModelIndex &index) const
         Qt::ItemFlags flags=QAbstractItemModel::flags(index);
 
         if (nodeTable) {
-                //       flags|=Qt::ItemIsEditable;
-
+                flags|=Qt::ItemIsEditable;
                 if (index.isValid()) flags|=Qt::ItemIsDragEnabled | Qt::ItemIsDropEnabled;
                 else flags|=Qt::ItemIsDropEnabled;
         }
@@ -559,6 +536,26 @@ Qt::ItemFlags SKGObjectModelBase::flags(const QModelIndex &index) const
 
 }
 
+bool SKGObjectModelBase::setData ( const QModelIndex & index, const QVariant& value, int role )
+{
+        if ( !index.isValid() ) return false;
+
+        if ( role == Qt::EditRole ) {
+                SKGError err;
+                if ( nodeTable ) {
+                        SKGNodeObject obj=getObject ( index );
+                        QString name=value.toString();
+                        SKGBEGINTRANSACTION(*getDocument(), i18n("Bookmark update [%1]", name), err);
+                        err=obj.setName(name);
+                        if (err.isSucceeded()) err=obj.save();
+                }
+
+                SKGMainPanel::displayErrorMessage ( err );
+                return err.isSucceeded();
+        }
+        return QAbstractItemModel::setData ( index, value, role );
+}
+
 Qt::DropActions SKGObjectModelBase::supportedDragActions() const
 {
         return (nodeTable ? Qt::MoveAction : Qt::IgnoreAction);
@@ -681,7 +678,8 @@ void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransact
                              nb=modifications.count();
                      }
 
-                     if (1==1 || iTableName=="node" || iTableName=="doctransaction" || getTable()=="v_operation_consolidated" || iIdTransaction==0 || nb>50) { //TODO: optimization*/
+                     if (1==1 || iTableName=="node" || iTableName=="doctransaction" || getTable()=="v_operation_consolidated" || iIdTransaction==0 || nb>50) {
+                */
                 //Full refresh
                 isResetRealyNeeded=true;
 
