@@ -43,7 +43,7 @@ Qt::SortOrder SKGTableWithGraph::sortOrder=Qt::AscendingOrder;
 int SKGTableWithGraph::sortColumn=0;
 
 SKGTableWithGraph::SKGTableWithGraph(QWidget *parent)
-                : QWidget(parent), scene(NULL), nbLevel(0), mainMenu(NULL)
+                : QWidget(parent), scene(NULL), nbLevel(0), showSumAndAverage(true), mainMenu(NULL)
 {
         ui.setupUi(this);
         ui.kLineUp->setIcon(KIcon("arrow-right"));
@@ -54,7 +54,6 @@ SKGTableWithGraph::SKGTableWithGraph(QWidget *parent)
         connect(ui.kTable, SIGNAL(customContextMenuRequested(const QPoint & ) ),this,SLOT(showMenu( const QPoint& )));
 
         mainMenu = new KMenu(ui.kTable);
-        mainMenu->addTitle(i18n("Table"));
 
         QMenu* exp=mainMenu->addMenu(i18n("Export"));
 
@@ -221,13 +220,15 @@ void SKGTableWithGraph::onFilterModified()
 }
 
 void SKGTableWithGraph::setData(const SKGStringListList& iData, const QString& iPrimaryUnit,
-                                const QString& iSecondaryUnit, double iSecondaryUnitValue)
+                                const QString& iSecondaryUnit, double iSecondaryUnitValue,
+                                bool iShowSumAndAverage)
 {
         SKGTRACEIN(10, "SKGTableWithGraph::setData");
         data=iData;
         primaryUnit=iPrimaryUnit;
         secondaryUnit=iSecondaryUnit;
         secondaryUnitValue=iSecondaryUnitValue;
+        showSumAndAverage=iShowSumAndAverage;
 
         refresh();
 
@@ -338,25 +339,22 @@ void SKGTableWithGraph::refresh()
 
         //Compute sums line
         int nblines=groupedTable.count();
-        {
-                int nblines=groupedTable.count();
-                {
-                        QStringList sums;
-                        sums.push_back(i18n("Sum"));
-                        for (int i=1; i<nbCols; ++i) {
-                                double sum=0;
-                                for (int j=1; j<nblines; ++j) {
-                                        sum+=SKGServices::stringToDouble(groupedTable.at(j).at(i));
-                                }
-                                sums.push_back(SKGServices::doubleToString(sum));
+        if (showSumAndAverage) {
+                QStringList sums;
+                sums.push_back(i18n("Sum"));
+                for (int i=1; i<nbCols; ++i) {
+                        double sum=0;
+                        for (int j=1; j<nblines; ++j) {
+                                sum+=SKGServices::stringToDouble(groupedTable.at(j).at(i));
                         }
-                        groupedTable.push_back(sums);
+                        sums.push_back(SKGServices::doubleToString(sum));
                 }
+                groupedTable.push_back(sums);
+                nblines++;
         }
-        nblines++;
 
         //Compute sum and average column
-        if (nbCols>2) {
+        if (nbCols>2 && showSumAndAverage) {
                 //Add title
                 QStringList newLine=groupedTable.at(0);
                 newLine.push_back(tr("Sum"));
@@ -385,14 +383,15 @@ void SKGTableWithGraph::refresh()
 
                 //Extract title and sums
                 QStringList fist=groupedTable.takeFirst();
-                QStringList last=groupedTable.takeLast();
+                QStringList last;
+                if (showSumAndAverage) last=groupedTable.takeLast();
 
                 //Sort
                 qSort(groupedTable.begin(), groupedTable.end(), listSort);
 
                 //Add title and sums
                 groupedTable.insert(0, fist);
-                groupedTable.push_back(last);
+                if (showSumAndAverage) groupedTable.push_back(last);
         }
 
         IFSKGTRACEL(10) {
@@ -462,7 +461,8 @@ void SKGTableWithGraph::onSelectionChanged(QTableWidgetItem* current, QTableWidg
                 if (graphicItem) {
                         graphicItem->setBrush(QBrush(QColor::fromHsv(graphicItem->data(11).toInt(),
                                                      graphicItem->data(12).toInt(),
-                                                     graphicItem->data(13).toInt())));
+                                                     graphicItem->data(13).toInt(),
+                                                     graphicItem->data(14).toInt())));
                         graphicItem->setSelected(false);
                 }
         }
@@ -528,10 +528,10 @@ void SKGTableWithGraph::redrawGraph()
                 int crow=ui.kTable->currentRow();
                 int ccolumn=ui.kTable->currentColumn();
 
-                int nbRows=ui.kTable->rowCount()-1; //Sum
+                int nbRows=ui.kTable->rowCount()-(showSumAndAverage ? 1 : 0); //Sum
                 int nbColumns=ui.kTable->columnCount();
                 int sumColumnIndex=nbColumns-1;
-                if (nbColumns>2) {
+                if (nbColumns>2 && showSumAndAverage) {
                         nbColumns=nbColumns-2; //Sum and average
                         --sumColumnIndex;
                 }
@@ -597,23 +597,29 @@ void SKGTableWithGraph::redrawGraph()
                                 maxX=width*nbRows+width;
                         } else if (mode==1) {
                                 width=(maxLimit-minLimit)/(nbRows*(nbColumns-1));
-                                maxX=width*(nbColumns-1)*nbRows+width;
+                                maxX=width*(nbColumns-1)*(nbRows+1)+width;
                         }
                 }
                 SKGTRACEL(30) << "width=" << width << endl;
                 SKGTRACEL(30) << "maxX=" << maxX << endl;
 
                 double margin=width;
-                if (mode!=2 && mode!=3) {//TODO for mode 2 or 3
+                int nbColInMode2=(nbColumns>2 && showSumAndAverage ? sqrt(nbColumns-1)+.5 : 1);
+                if (mode!=2 && mode!=3) {
                         scene->setSceneRect(-margin, -margin-maxLimit, maxX+margin, maxLimit-minLimit+2*margin);
                         scene->setItemIndexMethod(QGraphicsScene::NoIndex);
 
                         SKGTRACEL(10) << "Scene rect:" <<scene->sceneRect().x() << "," <<   scene->sceneRect().y()<< "," <<  scene->sceneRect().width()<< "," <<  scene->sceneRect().height() << endl;
                         SKGTRACEL(10) << "Items:" <<nbRows << "x" << (nbColumns-1) << "=" << nbRows*(nbColumns-1) << endl;
+                } else {
+                        int nbRowInMode2=((int) ((nbColumns-1)/nbColInMode2));
+                        if (nbRowInMode2*nbColInMode2<nbColumns-1) ++nbRowInMode2;
+
+                        scene->setSceneRect(0, 0, 120*nbColInMode2, 120*nbRowInMode2);
+                        scene->setItemIndexMethod(QGraphicsScene::NoIndex);
                 }
 
                 //Redraw scene
-                int nbColInMode2=(nbColumns>2 ? sqrt(nbColumns-1)+.5 : 1);
                 double ymin=0;
                 double ymax=0;
                 for (int x=0; x<nbRows; ++x) {
@@ -633,11 +639,14 @@ void SKGTableWithGraph::redrawGraph()
                                         int color_h=359*x/nbRows;
                                         int color_s=255-155*j/nbColumns;
                                         int color_v=255-155*j/nbColumns;
+                                        int color_a=200;
 
                                         QColor color;
                                         if (x==crow && j==ccolumn) color=QApplication::palette().color(QPalette::Highlight);
                                         else color=QColor::fromHsv(color_h,color_s,color_v);
 
+                                        color.setAlpha(color_a);
+
                                         QBrush brush(color);
 
                                         QAbstractGraphicsShapeItem* graphItem=NULL;
@@ -655,10 +664,10 @@ void SKGTableWithGraph::redrawGraph()
                                         } else if (mode==1) {
                                                 //HISTOGRAM
                                                 if (inPositive) {
-                                                        graphItem=scene->addRect(width*((j-1)*nbRows+x), 0, width, -fabs(val), QPen(), brush);
+                                                        graphItem=scene->addRect(width*((j-1)*(nbRows+1)+x), 0, width, -fabs(val), QPen(), brush);
                                                         if (fabs(val)>ymax) ymax=fabs(val);
                                                 } else {
-                                                        graphItem=scene->addRect(width*((j-1)*nbRows+x), 0, width, -val, QPen(), brush);
+                                                        graphItem=scene->addRect(width*((j-1)*(nbRows+1)+x), 0, width, -val, QPen(), brush);
                                                         if (val>ymax) ymax=val;
                                                         if (val<ymin) ymin=val;
                                                 }
@@ -708,6 +717,7 @@ void SKGTableWithGraph::redrawGraph()
                                                 graphItem->setData(11, color_h);
                                                 graphItem->setData(12, color_s);
                                                 graphItem->setData(13, color_v);
+                                                graphItem->setData(14, color_a);
                                                 graphItem->setCursor(Qt::PointingHandCursor);
 
                                                 tableItem->setData(1, (qlonglong)  graphItem);
@@ -721,6 +731,7 @@ void SKGTableWithGraph::redrawGraph()
                 //Draw axis
                 if (nbRows) {
                         if (mode==2 || mode==3) {
+                                //PIE
                                 int nbRowInMode2=((int) ((nbColumns-1)/nbColInMode2));
                                 if (nbRowInMode2*nbColInMode2<nbColumns-1) ++nbRowInMode2;
                                 for (int i=0; i<=nbColInMode2; ++i) {
@@ -745,12 +756,21 @@ void SKGTableWithGraph::redrawGraph()
 
                                 }
                         } else {
+                                //STACK & HISTOGRAMM
+                                double scaleText=0;
+
+                                //Axis y
                                 QGraphicsLineItem* item=scene->addLine(0, -ymin+margin, 0, -ymax-margin);
                                 item->setFlag(QGraphicsItem::ItemIsSelectable, false);
-
                                 addArrow(QPointF(0, -ymax-margin), margin/2, 45, 90);
 
-                                int ystep=100*((int) ((ymax-ymin)/1000));
+                                //Axis x
+                                item=scene->addLine(-margin, 0, maxX, 0);
+                                item->setFlag(QGraphicsItem::ItemIsSelectable, false);
+                                addArrow(QPointF(maxX, 0), margin/2, 45, 180);
+
+                                //Lines x
+                                int ystep=computeStepSize( ymax-ymin, 10 );
                                 if (ystep>0) {
                                         for (int y=ystep; y<ymax+margin; y=y+ystep) {
                                                 item=scene->addLine(-margin, -y, maxX, -y);
@@ -759,7 +779,11 @@ void SKGTableWithGraph::redrawGraph()
 
                                                 QGraphicsTextItem* textItem=scene->addText(SKGServices::intToString(y));
                                                 textItem->setPos(-margin, -y);
-                                                textItem->scale(ystep/40, ystep/40);
+                                                if (scaleText==0) {
+                                                        QRectF rect=textItem->boundingRect();
+                                                        scaleText=qMin(width/rect.width(), ystep/rect.height());
+                                                }
+                                                textItem->scale(scaleText, scaleText);
                                                 textItem->setFlag(QGraphicsItem::ItemIsSelectable, false);
                                         }
                                         for (int y=-ystep; y>ymin-margin; y=y-ystep) {
@@ -769,14 +793,29 @@ void SKGTableWithGraph::redrawGraph()
 
                                                 QGraphicsTextItem* textItem=scene->addText(SKGServices::intToString(y));
                                                 textItem->setPos(-margin, -y);
-                                                textItem->scale(ystep/40, ystep/40);
+                                                textItem->scale(scaleText, scaleText);
                                                 textItem->setFlag(QGraphicsItem::ItemIsSelectable, false);
                                         }
                                 }
-                                item=scene->addLine(-margin, 0, maxX, 0);
-                                item->setFlag(QGraphicsItem::ItemIsSelectable, false);
 
-                                addArrow(QPointF(maxX, 0), margin/2, 45, 180);
+                                if (mode==1) {
+                                        //Line y
+                                        int xstep=width*(nbRows+1);
+                                        int j=1;
+                                        for (int x=-width/2+xstep; x<maxX; x=x+xstep) {
+                                                QGraphicsLineItem* item=scene->addLine(x, -ymin+margin, x, -ymax-margin);
+                                                item->setPen(dotPen);
+                                                item->setFlag(QGraphicsItem::ItemIsSelectable, false);
+
+                                                QString yname=ui.kTable->horizontalHeaderItem(j)->text();
+                                                ++j;
+
+                                                QGraphicsTextItem* textItem=scene->addText(yname);
+                                                textItem->setPos(x-xstep, 0);
+                                                textItem->scale(scaleText, scaleText);
+                                                textItem->setFlag(QGraphicsItem::ItemIsSelectable, false);
+                                        }
+                                }
                         }
                 }
         }
@@ -794,6 +833,25 @@ void SKGTableWithGraph::redrawGraph()
         QApplication::restoreOverrideCursor();
 }
 
+double SKGTableWithGraph::computeStepSize( double iRange, double iTargetSteps )
+{
+        // Calculate an initial guess at step size
+        double tempStep = iRange / iTargetSteps;
+        // Get the magnitude of the step size
+        double mag = floor( log10( tempStep ) );
+        double magPow = pow( (double) 10.0, mag );
+        // Calculate most significant digit of the new step size
+        double magMsd = ( (int) ( tempStep / magPow + .5 ) );
+        // promote the MSD to either 1, 2, or 5
+        if ( magMsd > 5.0 )
+                magMsd = 10.0;
+        else if ( magMsd > 2.0 )
+                magMsd = 5.0;
+        else if ( magMsd > 1.0 )
+                magMsd = 2.0;
+        return magMsd * magPow;
+}
+
 void SKGTableWithGraph::addArrow(const QPointF& iPeak, double iSize, double iArrowAngle, double iDegree)
 {
         if (scene) {
@@ -831,6 +889,7 @@ void SKGTableWithGraph::onExportCSV()
                 }
 
                 //Close file
+                file.flush();
                 file.close();
 
         }
@@ -861,6 +920,7 @@ void SKGTableWithGraph::onExportTXT()
                 }
 
                 //Close file
+                file.flush();
                 file.close();
 
         }
