@@ -79,11 +79,13 @@ public:
          * @param iPrimaryUnit the primary unit
          * @param iSecondaryUnit the secondary unit
          * @param iSecondaryUnitValue the secondary unit value
+         * @param iShowSumAndAverage show sum and average columns
          */
         virtual void setData(const SKGStringListList& iData,
                              const QString& iPrimaryUnit,
                              const QString& iSecondaryUnit,
-                             double iSecondaryUnitValue);
+                             double iSecondaryUnitValue,
+                             bool iShowSumAndAverage=true);
 
         /**
          * Get the table content
@@ -128,6 +130,7 @@ private slots:
 private:
         Q_DISABLE_COPY(SKGTableWithGraph);
 
+        double computeStepSize( double iRange, double iTargetSteps );
         void addArrow(const QPointF& iPeak, double iSize, double iArrowAngle=45, double iDegree=90);
 
         static bool listSort(const QStringList &s1, const QStringList &s2);
@@ -143,6 +146,7 @@ private:
         QString primaryUnit;
         QString secondaryUnit;
         double secondaryUnitValue;
+        bool showSumAndAverage;
 
         KMenu* mainMenu;
 };
