@@ -15,7 +15,7 @@
  *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
  ***************************************************************************/
 /** @file
- * This file is Skrooge plugin for bank management.
+ * This file is a class managing widget.
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
@@ -31,7 +31,7 @@
 #include <QtGui/QWidget>
 
 SKGTabWidget::SKGTabWidget(SKGMainPanel* iParent, SKGDocument* iDocument)
-                : QWidget(), parent(iParent), document(iDocument)
+                : SKGWidget(iDocument), parent(iParent)
 {
         SKGTRACEIN(5, "SKGTabWidget::SKGTabWidget");
 }
@@ -39,7 +39,6 @@ SKGTabWidget::SKGTabWidget(SKGMainPanel* iParent, SKGDocument* iDocument)
 SKGTabWidget::~SKGTabWidget()
 {
         SKGTRACEIN(5, "SKGTabWidget::~SKGTabWidget");
-        document=NULL;
         parent=NULL;
 }
 
@@ -49,7 +48,7 @@ bool SKGTabWidget::close()
         //Is this widget linked to a bookmark ?
         if (bookmarkID.length()) {
                 //Yes. Is state modified ?
-                SKGNodeObject node(document, SKGServices::stringToInt(bookmarkID));
+                SKGNodeObject node(getDocument(), SKGServices::stringToInt(bookmarkID));
                 if (node.exist()) {
                         QStringList data=SKGServices::splitCSVLine(node.getData());
                         QString fullname=node.getFullName();
@@ -70,7 +69,7 @@ bool SKGTabWidget::close()
                                         if (conf==KMessageBox::Yes) {
                                                 SKGError err;
                                                 {
-                                                        SKGBEGINTRANSACTION(*document, tr("Bookmark update [%1]").arg(fullname), err);
+                                                        SKGBEGINTRANSACTION(*getDocument(), tr("Bookmark update [%1]").arg(fullname), err);
                                                         data[3]=currentState;
                                                         if (err.isSucceeded()) err=node.setData(SKGServices::stringsToCsv(data));
                                                         if (err.isSucceeded()) err=node.save();
@@ -101,25 +100,11 @@ SKGMainPanel * SKGTabWidget::getMainPanel()
         return parent;
 }
 
-SKGDocument * SKGTabWidget::getDocument()
-{
-        return document;
-}
-
 QWidget* SKGTabWidget::getWidgetForPrint()
 {
         return this;
 }
 
-QString SKGTabWidget::getState()
-{
-        return "";
-}
-
-void SKGTabWidget::setState(const QString& /*iState*/ )
-{
-}
-
 void SKGTabWidget::setBookmarkID(const QString& iId)
 {
         bookmarkID=iId;
