@@ -65,6 +65,11 @@ SKGDocument::~SKGDocument()
         progressData=NULL;
 }
 
+QString SKGDocument::getUniqueIdentifier()
+{
+        return uniqueIdentifier;
+}
+
 SKGDocument::DatabaseMode SKGDocument::getDatabaseMode()
 {
         return mode;
@@ -148,10 +153,6 @@ SKGError SKGDocument::beginTransaction(const QString & iName, int iNbStep, const
                                                               "','"+SKGServices::stringToSqlString(iName)+
                                                               "', "+SKGServices::intToString(getTransactionToTreat(SKGDocument::UNDO))+");");
                         currentTransaction=getTransactionToTreat(SKGDocument::UNDO);
-                        if (err.isSucceeded() && iName != "#INTERNAL#") {
-                                //Create undo redo temporary triggers
-                                err = createUndoRedoTemporaryTriggers();
-                        }
                 }
         } else {
                 //A transaction already exists
@@ -196,6 +197,11 @@ SKGError SKGDocument::endTransaction(bool succeedded)
 
                 if (nbStepForTransaction.size()==0) {
                         if (succeedded) {
+                                //Link items on current transaction
+                                if (err.isSucceeded()) {
+                                        err = SKGServices::executeSqliteOrder(this, "UPDATE doctransactionitem set rd_doctransaction_id="+SKGServices::intToString(getCurrentTransaction())+" WHERE rd_doctransaction_id=0;");
+                                }
+
                                 //Optimization of the current transaction
                                 if (err.isSucceeded()) {
                                         err = SKGServices::executeSqliteOrder(this, "DELETE FROM doctransaction WHERE id="+SKGServices::intToString(getCurrentTransaction())+" AND ((SELECT count(1) FROM doctransactionitem a where a.rd_doctransaction_id=doctransaction.id)=0);");
@@ -636,6 +642,26 @@ SKGError SKGDocument::changePassword(const QString & newPassword)
         return err;
 }
 
+SKGError SKGDocument::setLanguage(const QString& iLanguage)
+{
+        SKGError err;
+        SKGTRACEINRC(5, "SKGDocument::setLanguage", err);
+        QString previousLanguage=getParameter("SKGLANGUAGE");
+        if (previousLanguage!=iLanguage) {
+                //Save language into the document
+                if (err.isSucceeded()) err=beginTransaction("#INTERNAL#");
+                if (err.isSucceeded()) err=setParameter("SKGLANGUAGE", iLanguage);
+
+                //Migrate view for new language
+                if (err.isSucceeded()) err=refreshViewsIndexesAndTriggers();
+
+                //close temporary transaction
+                if (err.isSucceeded()) err=endTransaction(true);
+                else  endTransaction(false);
+        }
+        return err;
+}
+
 SKGError SKGDocument::initialize()
 {
         SKGError err;
@@ -661,8 +687,9 @@ SKGError SKGDocument::load(const QString & name, const QString & password)
                         err.setReturnCode(ERR_INVALIDARG);
                         err.setMessage(tr("File [%1] not found").arg(name));
                 } else {
+                        DatabaseMode dbMode=getDatabaseMode();
                         // open your memory database
-                        if (getDatabaseMode()==CopiedInMemory) {
+                        if (dbMode==CopiedInMemory) {
                                 //Create memory database
                                 currentDatabase=new QSqlDatabase(QSqlDatabase::addDatabase("QSQLITE", databaseIdentifier));
                                 currentDatabase->setDatabaseName(":memory:");
@@ -679,7 +706,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password)
                         if (err.isSucceeded()) {
                                 if (inputFile.exists()) {
                                         //File exist
-                                        if (getDatabaseMode()==DirectAccess) {
+                                        if (dbMode==DirectAccess) {
                                                 //Direct load of existing file
                                                 currentDatabase=new QSqlDatabase(QSqlDatabase::addDatabase("QSQLITE", databaseIdentifier));
                                                 currentDatabase->setDatabaseName(name);
@@ -688,7 +715,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password)
                                                         QSqlError sqlErr=currentDatabase->lastError();
                                                         err = SKGError(SQLLITEERROR + sqlErr.number(), sqlErr.text());
                                                 }
-                                        } else if (getDatabaseMode()==CopiedInFile) {
+                                        } else if (dbMode==CopiedInFile) {
                                                 //Copy in temporary file
                                                 temporaryFile=QDir::tempPath()+"/skrooge_"+QUuid::createUuid ().toString()+".skg";
                                                 QFile(temporaryFile).remove(); //Must must remove it to be able to copy
@@ -705,7 +732,7 @@ SKGError SKGDocument::load(const QString & name, const QString & password)
                                         } else {
                                                 //Copy in memory
                                                 {//This scope is needed to avoid a warning at remove
-                                                        QSqlDatabase dbfile = QSqlDatabase::addDatabase("QSQLITE", "TEMPORARY");
+                                                        QSqlDatabase dbfile = QSqlDatabase::addDatabase("QSQLITE", "TEMPORARY_LOAD");
                                                         dbfile.setDatabaseName(name);
                                                         if (!dbfile.open()) {
                                                                 //Set error message
@@ -713,19 +740,19 @@ SKGError SKGDocument::load(const QString & name, const QString & password)
                                                                 err = SKGError(SQLLITEERROR + sqlErr.number(), sqlErr.text());
                                                         } else {
                                                                 //Copy db from file to memory
-                                                                err = SKGServices::copySqliteDatabase(name, &dbfile, getDatabase(), true);
+                                                                err = SKGServices::copySqliteDatabase(&dbfile, getDatabase(), true);
 
                                                                 //Close
                                                                 dbfile.close();
                                                         }
                                                 }
                                                 //Remove database
-                                                QSqlDatabase::removeDatabase("TEMPORARY");
+                                                QSqlDatabase::removeDatabase("TEMPORARY_LOAD");
                                         }
 
                                         currentFileName=name;
                                 } else {
-                                        if (getDatabaseMode()==DirectAccess || getDatabaseMode()==CopiedInFile) {
+                                        if (dbMode==DirectAccess || dbMode==CopiedInFile) {
                                                 //Copy in temporary file
                                                 temporaryFile=QDir::tempPath()+"/skrooge_"+QUuid::createUuid ().toString()+".skg";
                                                 currentDatabase=new QSqlDatabase(QSqlDatabase::addDatabase("QSQLITE", databaseIdentifier));
@@ -816,9 +843,12 @@ SKGError SKGDocument::load(const QString & name, const QString & password)
                 err = SKGServices::executeSqliteOrder(this, "ANALYZE");
         }
 
+        //Creation undo/redo triggers
+        if (err.isSucceeded()) err = createUndoRedoTemporaryTriggers();
+
         if (err.isFailed() && !name.isEmpty()) {
                 err.addError(ERR_FAIL, tr("SKGDocument::load(%1,***) failed").arg(name));
-                initialize();
+                close();
         } else {
                 //Send event
                 emit tableModified("", 0);
@@ -875,7 +905,9 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
 
                 //Optimization
                 if (err.isSucceeded()) {
-                        err = SKGServices::executeSqliteOrder(this, "VACUUM;");
+                        DatabaseMode dbMode=getDatabaseMode();
+
+                        if (dbMode==SKGDocument::DirectAccess) err = SKGServices::executeSqliteOrder(this, "VACUUM;");
                         if (err.isSucceeded()) {
                                 //Check if file already exist
                                 if (!overwrite && QFile(name).exists()) {
@@ -884,16 +916,25 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                                         err.setMessage(tr("File [%1] already exist").arg(name));
                                 } else {
                                         //Open database
-                                        if (getDatabaseMode()==CopiedInMemory) {
+                                        if (dbMode==CopiedInMemory) {
+                                                //Create backup file
+                                                QFile::remove(name+".old");
+                                                QFile(name).copy(name+".old");
+
                                                 {//This scope is needed to avoid a warning at remove
                                                         //Remove previous file
-                                                        if (QFile(name).exists() && !QFile::remove(name)) {
+                                                        if (QFile(name).exists()) {
+                                                                SKGTRACEL(20) << "WARNING: [" << name << "] exists ==> remove it !" << endl;
+                                                                QFile::remove(name);
+                                                        }
+
+                                                        if (QFile(name).exists()) {
                                                                 //Set error message
                                                                 err.setReturnCode(ERR_FAIL);
                                                                 err.setMessage(tr("Impossible to remove [%1]").arg(name));
                                                         } else {
                                                                 //Copy memory in file
-                                                                QSqlDatabase dbfile = QSqlDatabase::addDatabase("QSQLITE", "TEMPORARY");
+                                                                QSqlDatabase dbfile = QSqlDatabase::addDatabase("QSQLITE", "TEMPORARY_SAVE");
                                                                 dbfile.setDatabaseName(name);
                                                                 if (!dbfile.open()) {
                                                                         //Set error message
@@ -901,7 +942,7 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                                                                         err = SKGError(SQLLITEERROR + sqlErr.number(), sqlErr.text());
                                                                 } else {
                                                                         //Copy db from memory to file
-                                                                        err = SKGServices::copySqliteDatabase(name, &dbfile, getDatabase(), false);
+                                                                        err = SKGServices::copySqliteDatabase(&dbfile, getDatabase(), false);
 
                                                                         //Close db
                                                                         dbfile.close();
@@ -910,20 +951,24 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                                                 }
 
                                                 //Remove database
-                                                QSqlDatabase::removeDatabase("TEMPORARY");
-                                        } else if (getDatabaseMode()==CopiedInFile) {
-                                                //Rename previous file
+                                                QSqlDatabase::removeDatabase("TEMPORARY_SAVE");
+                                        } else if (dbMode==CopiedInFile) {
+                                                //Create backup file
+                                                QFile::remove(name+".old");
                                                 QFile(name).rename(name+".old");
 
                                                 //Copy file to file
                                                 QString password=getParameter("SKG_PASSWORD");
                                                 err=SKGServices::cryptFile(temporaryFile, name, password, true);
 
-                                                //Remove previous file
-                                                if (err.isSucceeded()) QFile(name+".old").remove();
-                                                else QFile(name+".old").rename(name);
-                                        } else if (getDatabaseMode()==DirectAccess && !temporaryFile.isEmpty()) {
+                                                //Restore backup in case of failure
+                                                if (err.isFailed()) {
+                                                        QFile::remove(name);
+                                                        QFile(name+".old").rename(name);
+                                                }
+                                        } else if (dbMode==DirectAccess && !temporaryFile.isEmpty()) {
                                                 //Rename previous file
+                                                QFile::remove(name+".old");
                                                 QFile(name).rename(name+".old");
 
                                                 //Copy file to file
@@ -934,9 +979,11 @@ SKGError SKGDocument::saveAs(const QString & name, bool overwrite)
                                                         if (err.isSucceeded()) err=load(name);
                                                 }
 
-                                                //Remove previous file
-                                                if (err.isSucceeded()) QFile(name+".old").remove();
-                                                else QFile(name+".old").rename(name);
+                                                //Restore backup in case of failure
+                                                if (err.isFailed()) {
+                                                        QFile::remove(name);
+                                                        QFile(name+".old").rename(name);
+                                                }
                                         }
 
                                         if (err.isFailed()) err.addError(ERR_FAIL, tr("SKGDocument::saveAs(%1) failed").arg(name));
@@ -1152,8 +1199,10 @@ SKGError SKGDocument::migrate(bool& oMigrationDone)
                 err = setParameter("SKG_UNDO_MAX_DEPTH", SKGServices::intToString(SKG_UNDO_MAX_DEPTH));
         }
 
+        uniqueIdentifier=getParameter("SKG_UNIQUE_ID");
         if (getParameter("SKG_UNIQUE_ID").isEmpty()) {
-                err = setParameter("SKG_UNIQUE_ID", QUuid::createUuid ().toString());
+                uniqueIdentifier=QUuid::createUuid ().toString();
+                err = setParameter("SKG_UNIQUE_ID", uniqueIdentifier);
         }
 
         QString version = getParameter("SKG_DB_VERSION");
@@ -1266,7 +1315,6 @@ SKGError SKGDocument::createUndoRedoTemporaryTriggers() const
         SKGTRACEINRC(10, "SKGDocument::createUndoRedoTemporaryTriggers", err);
 
         //Create triggers
-        QString transactionId=SKGServices::intToString(getTransactionToTreat(SKGDocument::UNDO));
         QStringList tables;
         err=SKGServices::getTablesList(this, tables);
         int nbTables=tables.count();
@@ -1318,8 +1366,7 @@ SKGError SKGDocument::createUndoRedoTemporaryTriggers() const
                                                               //Create DELETE trigger
                                                               "CREATE TEMP TRIGGER UR_" + table + "_IN "
                                                               "AFTER  INSERT ON " + table + " BEGIN "
-                                                              "INSERT INTO doctransactionitem (rd_doctransaction_id, t_sqlorder,i_object_id,t_object_table,t_action) VALUES(" +transactionId+
-                                                              ",'DELETE FROM " + table +
+                                                              "INSERT INTO doctransactionitem (rd_doctransaction_id, t_sqlorder,i_object_id,t_object_table,t_action) VALUES(0,'DELETE FROM " + table +
                                                               " WHERE id='||new.id,new.id,'" + table + "','D');END;;"
 
                                                               //DROP UPDATE trigger
@@ -1328,8 +1375,7 @@ SKGError SKGDocument::createUndoRedoTemporaryTriggers() const
                                                               //Create UPDATE trigger
                                                               "CREATE TEMP TRIGGER UR_" + table + "_UP "
                                                               "AFTER UPDATE ON " + table + " BEGIN "
-                                                              "INSERT INTO doctransactionitem  (rd_doctransaction_id, t_sqlorder,i_object_id,t_object_table,t_action) VALUES(" +transactionId+
-                                                              ",'UPDATE " + table +
+                                                              "INSERT INTO doctransactionitem  (rd_doctransaction_id, t_sqlorder,i_object_id,t_object_table,t_action) VALUES(0,'UPDATE " + table +
                                                               " SET " + sqlorderForUpdate2 +
                                                               " WHERE id='||new.id,new.id,'" + table + "','U');END;;"
 
@@ -1340,8 +1386,7 @@ SKGError SKGDocument::createUndoRedoTemporaryTriggers() const
                                                               "CREATE TEMP TRIGGER UR_" + table + "_DE "
                                                               "AFTER DELETE ON " + table +
                                                               " BEGIN "
-                                                              "INSERT INTO doctransactionitem  (rd_doctransaction_id, t_sqlorder,i_object_id,t_object_table,t_action) VALUES(" +transactionId+
-                                                              ",'INSERT INTO " + table +
+                                                              "INSERT INTO doctransactionitem  (rd_doctransaction_id, t_sqlorder,i_object_id,t_object_table,t_action) VALUES(0,'INSERT INTO " + table +
                                                               '(' + sqlorderForInsert1 + ") VALUES(" + sqlorderForInsert2 + ")',old.id,'" + table + "','I'); END;;");
                 }
         }
@@ -1566,6 +1611,8 @@ QString SKGDocument::getDisplay(const QString& iString) const
         if (output.endsWith("t_name")) output=tr("Name");
         else if (output.endsWith("d_date")) output=tr("Date");
         else if (output.endsWith("t_savestep")) output=tr("Save");
+        else if (output.endsWith("t_value")) output=tr("Value");
+        else if (output.endsWith("d_lastmodifdate")) output=tr("Last modification");
         return output;
 }
 
