@@ -98,6 +98,12 @@ public:
          */
         virtual SKGDocument::DatabaseMode getDatabaseMode();
 
+        /**
+         * Get unique identifier
+         * @return the unique identifier
+         */
+        virtual QString getUniqueIdentifier();
+
         /**
          * Set the callback function to follow the progress of the transaction.
          * the first parameter is the progress between 0% and 100%.
@@ -239,6 +245,14 @@ public:
          */
         virtual SKGError changePassword(const QString & inewPassword);
 
+        /**
+         * Change the language of the document.
+         * @param iLanguage the new language
+         * @return an object managing the error
+         *   @see SKGError
+         */
+        virtual SKGError setLanguage(const QString& iLanguage);
+
         /**
          * Initialize a new document.
          * WARNING: This method must NOT be used in a transaction.
@@ -471,6 +485,7 @@ private:
         int currentTransaction;
         DatabaseMode mode;
         QString temporaryFile;
+        QString uniqueIdentifier;
         QStringList unTransactionnalMessages;
 
         QHash<QString, QString> cache;
