@@ -238,7 +238,6 @@ public:
         /**
          * Copy a sqlite database from memory to file or from file to memory.
          * It's used to do a load or a save
-         * @param iFileDbFile the filename of a sqlite database
          * @param iFileDb the sqlite pointer corresponding to iFileDbFile
          * @param iMemoryDb the sqlite pointer corresponding to  memory database
          * @param iFromFileToMemory
@@ -247,7 +246,7 @@ public:
          * @return An object managing the error
          *   @see SKGError
          */
-        static SKGError copySqliteDatabase(const QString& iFileDbFile, QSqlDatabase* iFileDb, QSqlDatabase* iMemoryDb, bool iFromFileToMemory);
+        static SKGError copySqliteDatabase(QSqlDatabase* iFileDb, QSqlDatabase* iMemoryDb, bool iFromFileToMemory);
 
         /**
          * Execute a sqlite order
