@@ -32,7 +32,7 @@
 void fileTest(SKGDocument::DatabaseMode iMode, int& nberror, int& nbcheck, bool showonlyfailures)
 {
         //test class SKGDocument / LOAD / SAVE
-        QString filename1 = getTestPath("IN")+"/filename1.skg";
+        QString filename1 = getTestPath("IN")+QString::fromUtf8("/filename1_e.skg"); //TODO: does not work if file name contains accents
         qDebug("filename1=%s", filename1.toUtf8().constData());
         {
                 SKGDocument document1(iMode);
