@@ -65,12 +65,12 @@ int main(int argc, char **argv)
                          KAboutData::License_GPL_V3,
                          ki18n("(c) 2007 Stephane MANKOWSKI & Guillaume DE BURE"),
                          KLocalizedString(),
-                         "http://skrooge.sourceforge.net",
-                         "miraks@users.sourceforge.net");
+                         "http://skrooge.sourceforge.net");
 
-        about.addAuthor( ki18n("Stephane MANKOWSKI"), ki18n("Architect & Developer"), "miraks@users.sourceforge.net" );
+        about.addAuthor( ki18n("Stephane MANKOWSKI"), ki18n("Architect & Developer"), "stephane@mankowski.fr" );
         about.addAuthor( ki18n("Guillaume DE BURE"), ki18n("Developer"), "willy9@users.sourceforge.net" );
-        about.addAuthor( ki18n("Thierry DAUCOURT"), ki18n("Graphist"), "thdox@users.sourceforge.net" );
+        about.addCredit( ki18n("Thierry DAUCOURT"), ki18n("Graphist & Tester"), "thdox@users.sourceforge.net" );
+        about.addCredit( ki18n("Georges GRAVA"), ki18n("Translator"), "bonfire_gga@users.sourceforge.net" );
         KCmdLineArgs::init(argc, argv, &about);
 
         KCmdLineOptions options;
@@ -101,16 +101,7 @@ int main(int argc, char **argv)
                 widget->show();
         }
 
-        int rc=0;
-        if (SKGServices::getenv("SKGTESTMODE").isEmpty()) {
-                rc=app.exec();
-                widget=NULL;
-        }
-
-        if (widget) {
-                delete widget;
-                widget=NULL;
-        }
+        int rc=app.exec();
         SKGTraces::exit(rc);
         return 0;
 }
