@@ -21,6 +21,7 @@
  */
 #include "skgbankplugin.h"
 #include "skgbankpluginwidget.h"
+#include "skgbankboardwidget.h"
 #include "skrooge_bank.h"
 #include "skgtraces.h"
 
@@ -54,6 +55,11 @@ void SKGBankPlugin::close()
         SKGTRACEIN(10, "SKGBankPlugin::close");
 }
 
+SKGWidget* SKGBankPlugin::getDashboardWidget()
+{
+        return new SKGBankBoardWidget(currentBankDocument);
+}
+
 SKGTabWidget* SKGBankPlugin::getWidget()
 {
         SKGTRACEIN(10, "SKGBankPlugin::getWidget");
@@ -63,10 +69,10 @@ SKGTabWidget* SKGBankPlugin::getWidget()
 QWidget* SKGBankPlugin::getPreferenceWidget()
 {
         SKGTRACEIN(10, "SKGBankPlugin::getPreferenceWidget");
-        QWidget* widget=new QWidget();
-        ui.setupUi(widget);
+        /*        QWidget* widget=new QWidget();
+                ui.setupUi(widget);*/
 
-        return widget;
+        return NULL;
 }
 
 KConfigSkeleton* SKGBankPlugin::getPreferenceSkeleton()
@@ -97,7 +103,7 @@ QString SKGBankPlugin::toolTip () const
 QStringList SKGBankPlugin::tips() const
 {
         QStringList output;
-        output.push_back(i18n("<p>... you can associate a logo to yours banks.</p>"));
+        output.push_back(i18n("<p>... you can associate a logo with your banks.</p>"));
         return output;
 }
 
