@@ -40,7 +40,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGBankPluginWidget(SKGMainPanel* iParent, SKGDocumentBank* iDocument);
+        SKGBankPluginWidget ( SKGMainPanel* iParent, SKGDocumentBank* iDocument );
 
         /**
          * Default Destructor
@@ -72,7 +72,14 @@ public:
          * MUST BE OVERWRITTEN
          * @param iState must be interpreted to set the state of the widget
          */
-        virtual void setState(const QString& iState);
+        virtual void setState ( const QString& iState );
+
+        /**
+         * Get attribute name to save the default state
+         * MUST BE OVERWRITTEN
+         * @return attribute name to save the default state.
+         */
+        virtual QString getDefaultStateAttibute();
 
         /**
          * Get the widget must be printed
@@ -80,13 +87,8 @@ public:
          */
         virtual QWidget* getWidgetForPrint();
 
-public slots:
-        /**
-         * Refresh the content.
-         */
-        virtual void refresh();
-
 private slots:
+        void dataModified(const QString& iTableName, int iIdTransaction);
         void onAccountCreatorModified();
         void onAddAccountClicked();
         void onModifyAccountClicked();
@@ -95,9 +97,15 @@ private slots:
         void onFilterChanged();
         void onFilterRegExpChanged();
         void onComputeRIB();
+        void onBtnModeClicked();
+
+        void refreshInfoZone();
 
 private:
-        Q_DISABLE_COPY(SKGBankPluginWidget);
+        Q_DISABLE_COPY ( SKGBankPluginWidget );
+
+        int getCurrentMode();
+        void setCurrentMode(int iMode);
 
         Ui::skgbankplugin_base ui;;
         SKGObjectModel* objectModel;
