@@ -51,6 +51,7 @@ SKGBookmarkPlugin::~SKGBookmarkPlugin()
         parent=NULL;
         currentBankDocument=NULL;
         dockWidget=NULL;
+        importStdCatAction=NULL;
 }
 
 void SKGBookmarkPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument)
@@ -78,7 +79,7 @@ void SKGBookmarkPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocume
         QStringList overlaybookmarks;
         overlaybookmarks.push_back("rating");
 
-        KAction* importStdCatAction = new KAction(KIcon("document-import", NULL, overlaybookmarks), i18n("Import standard &bookmarks"), this);
+        importStdCatAction = new KAction(KIcon("document-import", NULL, overlaybookmarks), i18n("Import standard &bookmarks"), this);
         connect(importStdCatAction, SIGNAL(triggered(bool)), SLOT(importStandardBookmarks()));
         actionCollection()->addAction( QLatin1String("import_standard_bookmarks"), importStdCatAction );
 
@@ -93,16 +94,21 @@ void SKGBookmarkPlugin::refresh()
                 if (p) p->refresh();
         }
 
-        //Automatic bookmarks creation
-        if (currentBankDocument && currentBankDocument->getDatabase()!=NULL) {
-                QString doc_id=currentBankDocument->getParameter("SKG_UNIQUE_ID");
-                if (docUniqueIdentifier!=doc_id) {
-                        docUniqueIdentifier=doc_id;
+        if (currentBankDocument) {
+                bool test=(currentBankDocument->getDatabase()!=NULL);
+                if (importStdCatAction) importStdCatAction->setEnabled(test);
 
-                        int nbNode=0;
-                        SKGError err=SKGObjectBase::getNbObjects(currentBankDocument, "node", "", nbNode);
-                        if (err.isSucceeded() && nbNode==0) {
-                                importStandardBookmarks();
+                //Automatic bookmarks creation
+                if (currentBankDocument->getDatabase()!=NULL) {
+                        QString doc_id=currentBankDocument->getUniqueIdentifier();
+                        if (docUniqueIdentifier!=doc_id) {
+                                docUniqueIdentifier=doc_id;
+
+                                int nbNode=0;
+                                SKGError err=SKGObjectBase::getNbObjects(currentBankDocument, "node", "", nbNode);
+                                if (err.isSucceeded() && nbNode==0) {
+                                        importStandardBookmarks();
+                                }
                         }
                 }
         }
@@ -134,7 +140,7 @@ QStringList SKGBookmarkPlugin::tips() const
         QString autostart=i18n("autostart");
         output.push_back(i18n("<p>... some bookmarks can be opened automatically when the skrooge is launched."));
         output.push_back(i18n("<p>... bookmarks can be reorganized by drag & drop.</p>"));
-        output.push_back(i18n("<p>... a double click on a folder of bookmarks will open all bookmarks under.</p>"));
+        output.push_back(i18n("<p>... a double click on a folder of bookmarks will open all the bookmarks it contains.</p>"));
         output.push_back(i18n("<p>... you can import standard bookmarks.</p>"));
         return output;
 }
