@@ -40,30 +40,26 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGMainPanel* iParent,
         SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget");
 
         ui.setupUi(this);
-        minSize=minimumSizeHint ();
-        ui.kActionsFrame->hide();
-
-        ui.kAddBookmarkGroup->setIcon(KIcon("folder-new"));
-        ui.kAddBookmark->setIcon(KIcon("list-add"));
-        ui.kRemoveBookmark->setIcon(KIcon("list-remove"));
-        ui.kRenameBookmark->setIcon(KIcon("edit-rename"));
 
+        ui.kBookmarksList->setEditTriggers(QAbstractItemView::NoEditTriggers);
         if (ui.kBookmarksList->isSmoothScrolling()) ui.kBookmarksList->switchSmoothScrolling();
 
         //Build contextual menu
         ui.kBookmarksList->setContextMenuPolicy(Qt::CustomContextMenu);
-        connect(ui.kBookmarksList, SIGNAL(customContextMenuRequested(const QPoint & ) ),this,SLOT(showMenu( const QPoint& )));
 
         mainMenu = new KMenu(ui.kBookmarksList);
-        actDelete = mainMenu->addAction(ui.kRemoveBookmark->icon(), i18n("Delete"));
+        actDelete = mainMenu->addAction(KIcon("list-remove"), i18n("Delete"));
         connect(actDelete, SIGNAL(triggered(bool)), this, SLOT(onRemoveBookmark()));
 
+        actRename = mainMenu->addAction(KIcon("edit-rename"), i18n("Rename"));
+        connect(actRename, SIGNAL(triggered(bool)), this, SLOT(onRenameBookmark()));
+
         mainMenu->addSeparator();
 
-        actAddBookmarkGroup = mainMenu->addAction(ui.kAddBookmarkGroup->icon(), ui.kAddBookmarkGroup->toolTip());
+        actAddBookmarkGroup = mainMenu->addAction(KIcon("folder-new"), i18n("Add bookmark group"));
         connect(actAddBookmarkGroup, SIGNAL(triggered(bool)), this, SLOT(onAddBookmarkGroup()));
 
-        actAddBookmark = mainMenu->addAction(ui.kAddBookmark->icon(), ui.kAddBookmark->toolTip());
+        actAddBookmark = mainMenu->addAction(KIcon("list-add"), i18n("Bookmark current page"));
         connect(actAddBookmark, SIGNAL(triggered(bool)), this, SLOT(onAddBookmark()));
 
         actSetAutostart = mainMenu->addAction(KIcon("user-online"), i18n("Autostart"));
@@ -72,16 +68,18 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(SKGMainPanel* iParent,
         actUnsetAutostart = mainMenu->addAction(KIcon("user-offline"), i18n("Remove Autostart"));
         connect(actUnsetAutostart, SIGNAL(triggered(bool)), this, SLOT(onUnsetAutostart()));
 
+        connect(ui.kBookmarksList, SIGNAL(customContextMenuRequested(const QPoint & ) ),this,SLOT(showMenu( const QPoint& )));
 
         //Add model
-        SKGObjectModelBase* modelview = new SKGObjectModelBase(getDocument(), "v_node", "r_node_id IS NULL OR r_node_id='' ORDER BY f_sortorder, t_name",
-                        this, "r_node_id=#ID# ORDER BY f_sortorder, t_name");
+        SKGObjectModelBase* modelview = new SKGObjectModelBase(getDocument(), "v_node", "1=1 ORDER BY f_sortorder, t_name", this, "r_node_id");
         SKGSortFilterProxyModel* modelproxy = new SKGSortFilterProxyModel(this);
         modelproxy->setSourceModel(modelview);
         ui.kBookmarksList->setModel(modelproxy);
 
         connect(ui.kBookmarksList->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(refresh()));
-        connect(ui.kBookmarksList, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onOpenBookmark()));
+        connect(ui.kBookmarksList, SIGNAL(pressed(QModelIndex)), this, SLOT(onBeforeOpenBookmark()));
+        connect(ui.kBookmarksList, SIGNAL(clicked(QModelIndex)), this, SLOT(onOpenBookmark(QModelIndex)));
+        connect(ui.kBookmarksList, SIGNAL(doubleClicked(QModelIndex)), this, SLOT(onOpenBookmarkFolder(QModelIndex)));
 }
 
 SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget()
@@ -89,6 +87,7 @@ SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget()
         SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::~SKGBookmarkPluginDockWidget");
         mainMenu=NULL;
         actDelete=NULL;
+        actRename=NULL;
         actAddBookmark=NULL;
         actAddBookmarkGroup=NULL;
         actSetAutostart=NULL;
@@ -100,27 +99,14 @@ void SKGBookmarkPluginDockWidget::showMenu(const QPoint& pos)
         if (mainMenu) mainMenu->popup(ui.kBookmarksList->mapToGlobal(pos));
 }
 
-int SKGBookmarkPluginDockWidget::getNbSelectedBookmarks()
+int SKGBookmarkPluginDockWidget::getNbSelectedObjects()
 {
-        QItemSelectionModel *selModel=ui.kBookmarksList->selectionModel();
-        return (selModel ? selModel->selectedRows().count() : 0);
+        return ui.kBookmarksList->getNbSelectedObjects();
 }
 
-SKGObjectBase::SKGListSKGObjectBase SKGBookmarkPluginDockWidget::getBookmarks()
+SKGObjectBase::SKGListSKGObjectBase SKGBookmarkPluginDockWidget::getSelectedObjects()
 {
-        //Get Selection
-        SKGObjectBase::SKGListSKGObjectBase selection;
-        QItemSelectionModel *selModel=ui.kBookmarksList->selectionModel();
-        QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kBookmarksList->model();
-        SKGObjectModelBase* model=(SKGObjectModelBase*) proxyModel->sourceModel();
-        if (model) {
-                QModelIndexList indexes=selModel->selectedRows();
-                foreach(const QModelIndex& index, indexes) {
-                        SKGObjectBase obj=model->getObject(proxyModel->mapToSource(index));
-                        selection.push_back(obj);
-                }
-        }
-        return selection;
+        return ui.kBookmarksList->getSelectedObjects();
 }
 
 void SKGBookmarkPluginDockWidget::onBookmarkFilterRegExpChanged()
@@ -147,7 +133,7 @@ void SKGBookmarkPluginDockWidget::setAutostart(const QString& value)
         SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::setAutostart");
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-        SKGObjectBase::SKGListSKGObjectBase selectedBookmarks = getBookmarks();
+        SKGObjectBase::SKGListSKGObjectBase selectedBookmarks = getSelectedObjects();
 
         SKGError err;
 
@@ -183,14 +169,14 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
         int nbTab=getMainPanel()->countTab();
         if (nbTab) {
                 setForcusOn=nbTab-1;
-                if (QApplication::keyboardModifiers()&Qt::ControlModifier) {
+                if (middleClick) {
                         setForcusOn=nbTab;
                 } else {
                         setForcusOn=getMainPanel()->currentTabIndex();
                 }
         }
 
-        int tabNumberForNextOpen=(QApplication::keyboardModifiers()&Qt::ControlModifier || iFirstInNewPage ? -1 : getMainPanel()->currentTabIndex());
+        int tabNumberForNextOpen=(middleClick || iFirstInNewPage ? -1 : getMainPanel()->currentTabIndex());
         for (int i=0; i<nodes.count(); ++i) { //WARNING: This list is modified dynamically
                 SKGNodeObject selectedNode=nodes.at(i);
                 QStringList data=SKGServices::splitCSVLine(selectedNode.getData());
@@ -218,12 +204,36 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
         QApplication::restoreOverrideCursor();
 }
 
-void SKGBookmarkPluginDockWidget::onOpenBookmark()
+void SKGBookmarkPluginDockWidget::onBeforeOpenBookmark()
+{
+        middleClick=QApplication::keyboardModifiers() &Qt::ControlModifier || QApplication::mouseButtons () &Qt::MidButton;
+}
+
+void SKGBookmarkPluginDockWidget::onOpenBookmark(const QModelIndex & index )
 {
         SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onOpenBookmark");
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        SKGObjectBase::SKGListSKGObjectBase bookmarks=getBookmarks();
-        if (bookmarks.count()) openBookmark(bookmarks.at(0));
+        QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kBookmarksList->model();
+        SKGObjectModelBase* model=(SKGObjectModelBase*) proxyModel->sourceModel();
+        if (model) {
+                SKGNodeObject node=model->getObject(proxyModel->mapToSource(index));
+                bool isFolder=node.getData().isEmpty();
+                if (!isFolder) openBookmark(node);
+        }
+        QApplication::restoreOverrideCursor();
+}
+
+void SKGBookmarkPluginDockWidget::onOpenBookmarkFolder(const QModelIndex & index )
+{
+        SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onOpenBookmarkFolder");
+        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+        QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kBookmarksList->model();
+        SKGObjectModelBase* model=(SKGObjectModelBase*) proxyModel->sourceModel();
+        if (model) {
+                SKGNodeObject node=model->getObject(proxyModel->mapToSource(index));
+                bool isFolder=node.getData().isEmpty();
+                if (isFolder) openBookmark(node);
+        }
         QApplication::restoreOverrideCursor();
 }
 
@@ -235,14 +245,14 @@ void SKGBookmarkPluginDockWidget::onAddBookmarkGroup()
         {
                 //Get current selection name
                 QString name;
-                SKGObjectBase::SKGListSKGObjectBase bookmarks=getBookmarks();
+                SKGObjectBase::SKGListSKGObjectBase bookmarks=getSelectedObjects();
                 if (bookmarks.count()) {
                         SKGNodeObject parentNode=bookmarks.at(0);
                         name=parentNode.getFullName();
                 }
 
                 //Add current name
-                QString namef=ui.kRenameBookmarkEdit->text();
+                QString namef=i18n("New bookmark");
                 if (namef.isEmpty()) namef=i18n("new bookmark folder");
 
                 if (!name.isEmpty()) name+=OBJECTSEPARATOR;
@@ -271,7 +281,7 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
         if (currentPage) {
                 //Get current selection name
                 QString name;
-                SKGObjectBase::SKGListSKGObjectBase bookmarks=getBookmarks();
+                SKGObjectBase::SKGListSKGObjectBase bookmarks=getSelectedObjects();
                 if (bookmarks.count()) {
                         SKGNodeObject parentNode=bookmarks.at(0);
                         name=parentNode.getFullName();
@@ -314,29 +324,21 @@ void SKGBookmarkPluginDockWidget::onAddBookmark()
 void SKGBookmarkPluginDockWidget::onRenameBookmark()
 {
         SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onRenameBookmark");
-        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 
-        //Get current selection
-        SKGError err;
-        SKGObjectBase::SKGListSKGObjectBase bookmarks=getBookmarks();
-        if (bookmarks.count()) {
-                SKGNodeObject parentNode=bookmarks.at(0);
-                {
-                        QString name=ui.kRenameBookmarkEdit->text();
-                        SKGBEGINTRANSACTION(*getDocument(), i18n("Bookmark update [%1]", name), err);
-                        err=parentNode.setName(name);
-                        if (err.isSucceeded()) err=parentNode.save();
+        SKGObjectBase::SKGListSKGObjectBase selection;
+        QItemSelectionModel *selModel=ui.kBookmarksList->selectionModel();
+        QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kBookmarksList->model();
+        if (proxyModel) {
+                SKGObjectModelBase* model=(SKGObjectModelBase*) proxyModel->sourceModel();
+                if (model) {
+                        QModelIndexList indexes=selModel->selectedRows();
+                        if (indexes.count()==1) {
+                                ui.kBookmarksList->edit ( indexes.at(0) );
+                        }
                 }
         }
-        QApplication::restoreOverrideCursor();
-
-        //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("Bookmark renamed"));
-        getMainPanel()->displayErrorMessage(err);
 }
 
-
-
 void SKGBookmarkPluginDockWidget::onRemoveBookmark()
 {
         SKGTRACEIN(1, "SKGBookmarkPluginDockWidget::onRemoveBookmark");
@@ -346,7 +348,7 @@ void SKGBookmarkPluginDockWidget::onRemoveBookmark()
         {
                 SKGBEGINTRANSACTION(*getDocument(), i18n("Bookmark delete"), err);
                 //Get current selection
-                SKGObjectBase::SKGListSKGObjectBase bookmarks=getBookmarks();
+                SKGObjectBase::SKGListSKGObjectBase bookmarks=getSelectedObjects();
                 int nb=bookmarks.count();
                 for (int i=0; i<nb && err.isSucceeded(); ++i) {
                         SKGNodeObject node=bookmarks.at(i);
@@ -366,7 +368,7 @@ void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
         SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::onBookmarkEditorChanged");
 
         //Bookmarks
-        SKGObjectBase::SKGListSKGObjectBase bookmarks=getBookmarks();
+        SKGObjectBase::SKGListSKGObjectBase bookmarks=getSelectedObjects();
         int nbSelectedObjects=bookmarks.count();
         int isFolder=true;
         if (nbSelectedObjects==1) {
@@ -376,21 +378,17 @@ void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
 
         //Enable bookmark buttons
         bool testAdd=getDocument()->getDatabase()!=NULL && nbSelectedObjects<=1 && isFolder;
-        ui.kAddBookmarkGroup->setEnabled(testAdd);
-        if (actAddBookmarkGroup) actAddBookmarkGroup->setEnabled(ui.kAddBookmarkGroup->isEnabled());
-        ui.kAddBookmark->setEnabled(testAdd && getMainPanel()->currentTabIndex()>=0);
-        if (actAddBookmark) actAddBookmark->setEnabled(ui.kAddBookmark->isEnabled());
-        ui.kRenameBookmark->setEnabled(nbSelectedObjects==1 && !ui.kRenameBookmarkEdit->text().isEmpty());
-        ui.kRemoveBookmark->setEnabled(nbSelectedObjects>0);
-        if (actDelete) actDelete->setEnabled(ui.kRemoveBookmark->isEnabled());
-        ui.kRenameBookmarkEdit->setEnabled(getDocument()->getDatabase()!=NULL && nbSelectedObjects<=1);
-
+        if (actAddBookmarkGroup) actAddBookmarkGroup->setEnabled(testAdd);
+        if (actAddBookmark) actAddBookmark->setEnabled(testAdd && getMainPanel()->currentTabIndex()>=0);
+        if (actDelete) actDelete->setEnabled(nbSelectedObjects>0);
+        if (actRename) actRename->setEnabled(nbSelectedObjects==1);
 }
+
 void SKGBookmarkPluginDockWidget::refresh()
 {
         SKGTRACEIN(10, "SKGBookmarkPluginDockWidget::refresh");
         //Automatic open of autostart bookmark
-        QString doc_id=getDocument()->getParameter("SKG_UNIQUE_ID");
+        QString doc_id=getDocument()->getUniqueIdentifier();
 
         if (docUniqueIdentifier!=doc_id) {
                 docUniqueIdentifier=doc_id;
@@ -406,12 +404,10 @@ void SKGBookmarkPluginDockWidget::refresh()
         }
 
         //Bookmarks
-        SKGObjectBase::SKGListSKGObjectBase bookmarks=getBookmarks();
+        SKGObjectBase::SKGListSKGObjectBase bookmarks=getSelectedObjects();
         int nbSelectedObjects=bookmarks.count();
         if (nbSelectedObjects==1) {
                 SKGNodeObject node=bookmarks.at(0);
-                ui.kRenameBookmarkEdit->setText(node.getName());
-
                 if (actSetAutostart) actSetAutostart->setEnabled(node.getAttribute("t_autostart")!="Y");
                 if (actUnsetAutostart) actUnsetAutostart->setEnabled(node.getAttribute("t_autostart")=="Y");
         }
@@ -423,18 +419,10 @@ void SKGBookmarkPluginDockWidget::resizeEvent(QResizeEvent *event)
 {
         if (event) {
                 QSize newSize=event->size ();
-                if (newSize.height()<=minSize.height() || newSize.width()<=minSize.width()) {
-                        ui.kActionsFrame->hide();
-                } else {
-                        ui.kActionsFrame->show();
-                }
 
                 //Compute icon size
                 int s=qMax(qMin(newSize.width()/5,64),16);
                 ui.kBookmarksList->setIconSize(QSize(s, s));
-
-                //TODO: must be fixed
-                getMainPanel()->contextList()->setIconSize(QSize(s, s));
         }
 
         QWidget::resizeEvent(event);
