@@ -49,13 +49,13 @@ public:
          * Get the current selected bookmarks
          * @return selected bookmarks
          */
-        virtual SKGObjectBase::SKGListSKGObjectBase getBookmarks();
+        virtual SKGObjectBase::SKGListSKGObjectBase getSelectedObjects();
 
         /**
          * Get the number of seleted bookmarks
          * @return number of selected bookmarks
          */
-        virtual int getNbSelectedBookmarks();
+        virtual int getNbSelectedObjects();
 
         /**
          * Open a bookmark
@@ -84,7 +84,9 @@ private slots:
         void onAddBookmark();
         void onRemoveBookmark();
         void onRenameBookmark();
-        void onOpenBookmark();
+        void onBeforeOpenBookmark();
+        void onOpenBookmark(const QModelIndex & index );
+        void onOpenBookmarkFolder(const QModelIndex & index );
         void onBookmarkEditorChanged();
         void onBookmarkFilterRegExpChanged();
         void onSetAutostart();
@@ -99,11 +101,12 @@ private:
         QString docUniqueIdentifier;
         KMenu* mainMenu;
         QAction* actDelete;
+        QAction* actRename;
         QAction* actAddBookmark;
         QAction* actAddBookmarkGroup;
         QAction* actSetAutostart;
         QAction* actUnsetAutostart;
-        QSize minSize;
+        bool middleClick;
 };
 
 #endif // SKGBOOKMARKPLUGINDOCKWIDGET_H
