@@ -38,7 +38,7 @@ K_PLUGIN_FACTORY(SKGCategoriesPluginFactory, registerPlugin<SKGCategoriesPlugin>
 K_EXPORT_PLUGIN(SKGCategoriesPluginFactory("skrooge_categories", "skrooge_categories"));
 
 SKGCategoriesPlugin::SKGCategoriesPlugin(QObject* iParent, const QVariantList& /*iArg*/)
-                :SKGInterfacePlugin(iParent), parent(NULL), currentBankDocument(NULL)
+                :SKGInterfacePlugin(iParent), parent(NULL), currentBankDocument(NULL), importStdCatAction(NULL)
 {
         SKGTRACEIN(10, "SKGCategoriesPlugin::SKGCategoriesPlugin");
 }
@@ -48,6 +48,7 @@ SKGCategoriesPlugin::~SKGCategoriesPlugin()
         SKGTRACEIN(10, "SKGCategoriesPlugin::~SKGCategoriesPlugin");
         parent=NULL;
         currentBankDocument=NULL;
+        importStdCatAction=NULL;
 }
 
 void SKGCategoriesPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument)
@@ -66,7 +67,7 @@ void SKGCategoriesPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocu
         QStringList overlaycategories;
         overlaycategories.push_back("skrooge_category");
 
-        KAction* importStdCatAction = new KAction(KIcon("document-import", NULL, overlaycategories), i18n("Import standard &categories"), this);
+        importStdCatAction = new KAction(KIcon("document-import", NULL, overlaycategories), i18n("Import standard &categories"), this);
         connect(importStdCatAction, SIGNAL(triggered(bool)), SLOT(importStandardCategories()));
         actionCollection()->addAction( QLatin1String("import_standard_categories"), importStdCatAction );
 
@@ -76,27 +77,32 @@ void SKGCategoriesPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocu
 void SKGCategoriesPlugin::refresh()
 {
         SKGTRACEIN(10, "SKGCategoriesPlugin::refresh");
-        //Automatic categories creation
-        if (currentBankDocument && currentBankDocument->getDatabase()!=NULL) {
-                QString doc_id=currentBankDocument->getParameter("SKG_UNIQUE_ID");
-                if (docUniqueIdentifier!=doc_id) {
-                        docUniqueIdentifier=doc_id;
+        if (currentBankDocument) {
+                bool test=(currentBankDocument->getDatabase()!=NULL);
+                if (importStdCatAction) importStdCatAction->setEnabled(test);
 
-                        int nbCategory=0;
-                        SKGError err=SKGObjectBase::getNbObjects(currentBankDocument, "category", "", nbCategory);
-                        if (err.isSucceeded() && nbCategory==0) {
-                                QFile file(KStandardDirs::locate("data", QString::fromLatin1("skrooge/ressources/default_categories.rc")));
-                                if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+                //Automatic categories creation
+                if (currentBankDocument->getDatabase()!=NULL) {
+                        QString doc_id=currentBankDocument->getUniqueIdentifier();
+                        if (docUniqueIdentifier!=doc_id) {
+                                docUniqueIdentifier=doc_id;
 
-                                        QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
-                                        int rc=KMessageBox::questionYesNo(parent, i18n("Do you want to import standard categories ?"));
-                                        QApplication::restoreOverrideCursor();
-                                        if (rc==KMessageBox::Yes) {
-                                                importStandardCategories();
+                                int nbCategory=0;
+                                SKGError err=SKGObjectBase::getNbObjects(currentBankDocument, "category", "", nbCategory);
+                                if (err.isSucceeded() && nbCategory==0) {
+                                        QFile file(KStandardDirs::locate("data", QString::fromLatin1("skrooge/ressources/default_categories.rc")));
+                                        if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+
+                                                QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+                                                int rc=KMessageBox::questionYesNo(parent, i18n("Do you want to import standard categories?"));
+                                                QApplication::restoreOverrideCursor();
+                                                if (rc==KMessageBox::Yes) {
+                                                        importStandardCategories();
+                                                }
+                                                file.close();
+                                        } else {
+                                                SKGTRACE << file.fileName() << " does not exits for language [" << KGlobal::locale()->language() << "]" << endl;
                                         }
-                                        file.close();
-                                } else {
-                                        SKGTRACE << file.fileName() << " does not exits for language [" << KGlobal::locale()->language() << "]" << endl;
                                 }
                         }
                 }
@@ -131,7 +137,7 @@ void SKGCategoriesPlugin::importStandardCategories()
 
         //status
         if (err.isSucceeded())  err=SKGError(0, i18n("Standard categories imported."));
-        else err.addError(ERR_FAIL, i18n("Import standard categories failed"));
+        else err.addError(ERR_FAIL, i18n("Importing standard categories failed."));
 
         //Display error
         if (parent) parent->displayErrorMessage(err);
