@@ -45,19 +45,14 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGMainPanel* iParent, SKGD
         ui.kAddCategoryButton->setIcon(KIcon("list-add"));
         ui.kModifyCategoryButton->setIcon(KIcon("dialog-ok-apply"));
 
-        SKGObjectModel* objectModel = new SKGObjectModel((SKGDocumentBank*) getDocument(), "v_category_display",
-                        "r_category_id IS NULL OR r_category_id=''",
-                        this, "r_category_id=#ID#");
+        objectModel = new SKGObjectModel((SKGDocumentBank*) getDocument(), "v_category_display",
+                                         "1=0", this, "r_category_id");
         SKGSortFilterProxyModel* modelproxy = new SKGSortFilterProxyModel(this);
         modelproxy->setSourceModel(objectModel);
         modelproxy->setSortRole(Qt::UserRole);
         modelproxy->setDynamicSortFilter(true);
         ui.kCategoriesView->setModel(modelproxy);
         ui.kCategoriesView->setWindowTitle(i18n("Categories"));
-        ui.kCategoriesView->setDefaultSaveParameters(getDocument(), "SKG_DEFAULT_CATEGORY");
-
-        //Set view parameters
-        ui.kCategoriesView->sortByColumn(0, Qt::AscendingOrder);
 
         //Add registered global action in contextual menu
         if (iParent) {
@@ -71,30 +66,32 @@ SKGCategoriesPluginWidget::SKGCategoriesPluginWidget(SKGMainPanel* iParent, SKGD
                 ui.kCategoriesView->header()->setStretchLastSection(false);
         }
 
-        ui.kTitle->setPixmap(KIcon("dialog-information").pixmap(22, 22));
+        ui.kTitle->setPixmap(KIcon("dialog-information").pixmap(22, 22), KTitleWidget::ImageLeft);
 
-        refresh();
-        connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(refresh()), Qt::QueuedConnection);
+        connect((const QObject*) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)), Qt::QueuedConnection );
+        dataModified("", 0);
 
-        connect(ui.kCategoriesView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                this, SLOT(onSelectionChanged()));
+        connect(ui.kCategoriesView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
 
-        connect(objectModel, SIGNAL(modelAboutToBeReset()), ui.kCategoriesView, SLOT(saveSelection()));
-        connect(objectModel, SIGNAL(modelReset()), ui.kCategoriesView, SLOT(resetSelection()));
+        connect(objectModel, SIGNAL(beforeReset()), ui.kCategoriesView, SLOT(saveSelection()));
+        connect(objectModel, SIGNAL(afterReset()), ui.kCategoriesView, SLOT(resetSelection()));
 }
 
 SKGCategoriesPluginWidget::~SKGCategoriesPluginWidget()
 {
         SKGTRACEIN(10, "SKGCategoriesPluginWidget::~SKGCategoriesPluginWidget");
+        objectModel=NULL;
 }
 
-void SKGCategoriesPluginWidget::refresh()
+void SKGCategoriesPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-        SKGTRACEIN(10, "SKGCategoriesPluginWidget::refresh");
-        //Correction bug 2299394 vvv
-        if (ui.kCategoriesView->isAutoResized()) ui.kCategoriesView->resizeColumnsToContents();
-        //Correction bug 2299394 ^^^
-        onEditorModified();
+        SKGTRACEIN(10, "SKGCategoriesPluginWidget::dataModified");
+        if (iTableName=="category" || iTableName.isEmpty()) {
+                //Correction bug 2299394 vvv
+                if (ui.kCategoriesView->isAutoResized()) ui.kCategoriesView->resizeColumnsToContents();
+                //Correction bug 2299394 ^^^
+                onEditorModified();
+        }
 }
 
 void SKGCategoriesPluginWidget::onSelectionChanged()
@@ -114,25 +111,12 @@ void SKGCategoriesPluginWidget::onSelectionChanged()
 
 SKGObjectBase::SKGListSKGObjectBase SKGCategoriesPluginWidget::getSelectedObjects()
 {
-        //Get Selection
-        SKGObjectBase::SKGListSKGObjectBase selection;
-        QItemSelectionModel *selModel=ui.kCategoriesView->selectionModel();
-        QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kCategoriesView->model();
-        SKGObjectModel* model=(SKGObjectModel*) proxyModel->sourceModel();
-        if (model) {
-                QModelIndexList indexes=selModel->selectedRows();
-                foreach(const QModelIndex& index, indexes) {
-                        SKGObjectBase obj=model->getObject(proxyModel->mapToSource(index));
-                        selection.push_back(obj);
-                }
-        }
-        return selection;
+        return ui.kCategoriesView->getSelectedObjects();
 }
 
 int SKGCategoriesPluginWidget::getNbSelectedObjects()
 {
-        QItemSelectionModel *selModel=ui.kCategoriesView->selectionModel();
-        return (selModel ? selModel->selectedRows().count() : 0);
+        return ui.kCategoriesView->getNbSelectedObjects();
 }
 
 QString SKGCategoriesPluginWidget::getState()
@@ -154,7 +138,21 @@ void SKGCategoriesPluginWidget::setState(const QString& iState )
         doc.setContent(iState);
         QDomElement root = doc.documentElement();
 
+        if ( objectModel ) {
+                objectModel->setFilter ( "1=1" );
+        }
+
+        //!!! Must be done here after onFilterChanged
         ui.kCategoriesView->setState(root.attribute ( "view"));
+
+        //Correction bug 2299394 vvv
+        if ( ui.kCategoriesView->isAutoResized() ) ui.kCategoriesView->resizeColumnsToContents();
+        //Correction bug 2299394 ^^^
+}
+
+QString SKGCategoriesPluginWidget::getDefaultStateAttibute()
+{
+        return "SKGCATEGORIES_DEFAULT_PARAMETERS";
 }
 
 QWidget* SKGCategoriesPluginWidget::getWidgetForPrint()
@@ -193,7 +191,7 @@ void SKGCategoriesPluginWidget::onAddCategory()
         }
 
         //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("Category [%1] created", name));
+        if (err.isSucceeded())  err=SKGError(0, i18n("Category [%1] created", name));
         else err.addError(ERR_FAIL, i18n("Category creation failed"));
         QApplication::restoreOverrideCursor();
 
@@ -263,13 +261,18 @@ void SKGCategoriesPluginWidget::onDoubleClick()
                 } else {
                         //Call operation plugin
                         QDomDocument doc("SKGML");
-                        QDomElement root = doc.createElement("parameters");
-                        doc.appendChild(root);
+                        doc.setContent ( getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
+                        QDomElement root = doc.documentElement();
+                        if (root.isNull()) {
+                                root=doc.createElement("parameters");
+                                doc.appendChild(root);
+                        }
+
                         root.setAttribute("operationTable", "v_operation_consolidated");
                         root.setAttribute("operationWhereClause", wc);
                         root.setAttribute("title", title);
                         root.setAttribute("title_icon", "view-statistics");
-
+                        root.setAttribute ( "currentPage", "-1" );
 
                         getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
                 }
