@@ -27,6 +27,7 @@
 #include <QStringList>
 
 class SKGDocumentBank;
+class SKGObjectModel;
 
 /**
  * This file is Skrooge plugin to generate categories
@@ -73,19 +74,21 @@ public:
          */
         virtual void setState(const QString& iState);
 
+        /**
+         * Get attribute name to save the default state
+         * MUST BE OVERWRITTEN
+         * @return attribute name to save the default state.
+         */
+        virtual QString getDefaultStateAttibute();
+
         /**
          * Get the widget must be printed
          * @return a widget
          */
         virtual QWidget* getWidgetForPrint();
 
-public slots:
-        /**
-         * Refresh the panel
-         */
-        void refresh();
-
 private slots:
+        void dataModified(const QString& iTableName, int iIdTransaction);
         void onDoubleClick();
         void onSelectionChanged();
         void onEditorModified();
@@ -96,6 +99,7 @@ private:
         Q_DISABLE_COPY(SKGCategoriesPluginWidget);
 
         Ui::skgcategoriesplugin_base ui;
+        SKGObjectModel* objectModel;
 };
 
 #endif // SKGCATEGORIESPLUGINWIDGET_H
