@@ -65,11 +65,6 @@ SKGDebugPluginWidget::SKGDebugPluginWidget(SKGMainPanel* iParent, SKGDocument* i
         for (int i=0; i<nb; ++i) {
                 ui.kSQLInput->addItem("PRAGMA index_info("+tables[i]+");");
         }
-
-        //Refresh
-        connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(refresh()), Qt::QueuedConnection);
-
-        refresh();
 }
 
 SKGDebugPluginWidget::~SKGDebugPluginWidget()
@@ -127,7 +122,7 @@ void SKGDebugPluginWidget::onExecuteSqlOrder(bool iInTransaction)
         QString oResult;
         double time=SKGServices::getMicroTime();
         if (iInTransaction) {
-                SKGBEGINTRANSACTION(*getDocument(), i18n("SQL order from debug plugin"), err);
+                SKGBEGINTRANSACTION(*getDocument(), i18n("SQL command from debug plugin"), err);
                 err=SKGServices::dumpSelectSqliteOrder(getDocument(), text, oResult);
         } else {
                 err=SKGServices::dumpSelectSqliteOrder(getDocument(), text, oResult);
@@ -168,13 +163,4 @@ void SKGDebugPluginWidget::onRefreshViewsAndIndexes()
         QApplication::restoreOverrideCursor();
 }
 
-void SKGDebugPluginWidget::refresh()
-
-{
-        SKGTRACEIN(10, "SKGDebugPluginWidget::refresh");
-
-        //Refresh widgets
-        setEnabled(getDocument()->getDatabase()!=NULL);
-}
-
 #include "skgdebugpluginwidget.moc"
