@@ -56,6 +56,7 @@ SKGFilePlugin::~SKGFilePlugin()
         recentFiles=NULL;
         saveAction=NULL;
         saveAsAction=NULL;
+        passwordAction=NULL;
 }
 
 void SKGFilePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument)
@@ -82,7 +83,7 @@ void SKGFilePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument,
         saveAsAction=KStandardAction::saveAs(this, SLOT(actionSaveAs()), actionCollection());
         if (parent) parent->registedGlobalAction("file_save_as", saveAsAction);
 
-        KAction* passwordAction = new KAction(KIcon("document-encrypt"), i18n("&Change password..."), this);
+        passwordAction = new KAction(KIcon("document-encrypt"), i18n("&Change password..."), this);
         connect(passwordAction, SIGNAL(triggered(bool)), this, SLOT(actionChangePassword()));
         actionCollection()->addAction( QLatin1String("file_change_password"), passwordAction );
         passwordAction->setShortcut(Qt::CTRL+Qt::Key_K);
@@ -101,7 +102,7 @@ void SKGFilePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument,
                 QString filename=iArgument.at(nbArg-1);
                 if (parent) {
                         KSplashScreen* splashScreen=parent->splashScreen();
-                        if (splashScreen) splashScreen->showMessage(i18n("Opening file %1 ...", filename), Qt::AlignLeft, QColor(221, 130, 8));
+                        if (splashScreen) splashScreen->showMessage(i18n("Opening file %1...", filename), Qt::AlignLeft, QColor(221, 130, 8));
                 }
                 emit loadFile(filename);
         } else {
@@ -115,7 +116,7 @@ void SKGFilePlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument,
                         if (!lastOpenedFile.isEmpty() && QFile(lastOpenedFile).exists()) {
                                 if (parent) {
                                         KSplashScreen* splashScreen=parent->splashScreen();
-                                        if (splashScreen) splashScreen->showMessage(i18n("Opening file %1 ...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));
+                                        if (splashScreen) splashScreen->showMessage(i18n("Opening file %1...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));
                                 }
                                 emit loadFile(lastOpenedFile);
                         }
@@ -145,8 +146,10 @@ void SKGFilePlugin::refresh()
 
         //Refresh action status
         if (currentBankDocument) {
-                if (saveAction) saveAction->setEnabled(currentBankDocument->isFileModified() && currentBankDocument->getCurrentFileName().length()>0);
-                if (saveAsAction) saveAsAction->setEnabled(currentBankDocument->getDatabase()!=NULL);
+                bool test=(currentBankDocument->getDatabase()!=NULL);
+                if (saveAction) saveAction->setEnabled(currentBankDocument->isFileModified());
+                if (saveAsAction) saveAsAction->setEnabled(test);
+                if (passwordAction) passwordAction->setEnabled(test);
         }
 }
 
@@ -162,7 +165,7 @@ QString SKGFilePlugin::icon() const
 
 QString SKGFilePlugin::statusTip () const
 {
-        return i18n("File management (open, save, save as ...)");
+        return i18n("File management (open, save, save as, ...)");
 }
 
 QString SKGFilePlugin::toolTip () const
@@ -173,7 +176,7 @@ QString SKGFilePlugin::toolTip () const
 QStringList SKGFilePlugin::tips() const
 {
         QStringList output;
-        output.push_back(i18n("<p>... last opened file can be open automatically when skrooge is launched.</p>"));
+        output.push_back(i18n("<p>... the last opened file can be open automatically when skrooge is launched.</p>"));
         output.push_back(i18n("<p>... you can secure your document with a password.</p>"));
         return output;
 }
@@ -199,12 +202,13 @@ void SKGFilePlugin::actionNew()
                 parent->closeAllTabs();
 
                 err=currentBankDocument->initialize();
+
+                KLocale* locale=KGlobal::locale();
+                if (err.isSucceeded()) err=currentBankDocument->setLanguage(locale->language());
                 if (err.isSucceeded()) {
                         SKGBEGINTRANSACTION(*currentBankDocument, i18n("Create default unit"), err);
                         if (err.isSucceeded()) {
                                 //Create default unit
-                                KLocale* locale=KGlobal::locale();
-
                                 //Creation of PRIMARY unit
                                 QString currencySymbol=locale->currencySymbol();
                                 QString language=locale->language();
@@ -240,7 +244,7 @@ void SKGFilePlugin::actionNew()
 
                 //status bar
                 if (err.isSucceeded()) err=SKGError(0, i18n("Document successfully created."));
-                else err.addError(ERR_FAIL, i18n("Document creation failed"));
+                else err.addError(ERR_FAIL, i18n("Document creation failed."));
 
                 //Display error
                 if (parent) parent->displayErrorMessage(err);
@@ -252,19 +256,23 @@ void SKGFilePlugin::actionSave()
         SKGError err;
         SKGTRACEINRC(10, "SKGFilePlugin::actionSave",err);
         if (currentBankDocument && parent) {
-                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-                err=currentBankDocument->save();
-                QApplication::restoreOverrideCursor();
+                if (currentBankDocument->getCurrentFileName().length()==0) {
+                        actionSaveAs();
+                } else {
+                        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+                        err=currentBankDocument->save();
+                        QApplication::restoreOverrideCursor();
 
-                //Refresh
-                parent->refresh();
+                        //Refresh
+                        parent->refresh();
 
-                //status bar
-                if (err.isSucceeded()) err=SKGError(0, i18n("File successfully saved."));
-                else err.addError(ERR_FAIL, i18n("Cannot save file"));
+                        //status bar
+                        if (err.isSucceeded()) err=SKGError(0, i18n("File successfully saved."));
+                        else err.addError(ERR_FAIL, i18n("Cannot save file"));
 
-                //Display error
-                parent->displayErrorMessage(err);
+                        //Display error
+                        parent->displayErrorMessage(err);
+                }
         }
 }
 
@@ -296,7 +304,7 @@ void SKGFilePlugin::actionSaveAs()
                         KConfigGroup pref=config->group("File");
                         pref.writePathEntry("lastfilepath",fileName);
 
-                } else err.addError(ERR_FAIL, i18n("Save of [%1] failed", fileName));
+                } else err.addError(ERR_FAIL, i18n("Failed to save [%1].", fileName));
 
                 //Display error
                 parent->displayErrorMessage(err);
@@ -318,8 +326,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
                         QApplication::restoreOverrideCursor();
 
                         if (err.isFailed()) {
-                                KSplashScreen* splashScreen=parent->splashScreen();
-                                if (splashScreen) splashScreen->hide();
+                                currentBankDocument->close();
 
                                 //Open failed
                                 //Password must be asked
@@ -334,22 +341,26 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
                                         uipwd.kLabel1->setText(i18n("Password:"));
                                         uipwd.kLabel2->hide();
                                         uipwd.kTitle->setText(additionnalMessage+i18n("This file seems to be protected.\nPlease enter the password."));
-                                        uipwd.kTitle->setPixmap(KIcon("document-decrypt").pixmap(48, 48));
+                                        uipwd.kTitle->setPixmap(KIcon("document-decrypt").pixmap(48, 48), KTitleWidget::ImageLeft);
                                         uipwd.kPwd1->setFocus();
                                         if (d->exec()==QDialog::Accepted) {
+                                                KSplashScreen* splashScreen=parent->splashScreen();
+                                                if (splashScreen) splashScreen->hide();
+
                                                 QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
                                                 err=currentBankDocument->load(fileName, uipwd.kPwd1->text());
                                                 if (err.isFailed()) {
-                                                        additionnalMessage=i18n("Wrong password !\n");
+                                                        additionnalMessage=i18n("Wrong password.\n");
                                                 }
                                                 QApplication::restoreOverrideCursor();
+
+                                                if (splashScreen) splashScreen->show();
                                         }
                                 } while (err.isFailed());
-
-                                if (splashScreen) splashScreen->show();
                         }
-                        if (err.isFailed()) currentBankDocument->initialize();
+                        if (err.isFailed()) err=currentBankDocument->initialize();
 
+                        if (err.isSucceeded()) err=currentBankDocument->setLanguage(KGlobal::locale()->language());
 
                         //status bar
                         if (err.isSucceeded()) {
@@ -363,7 +374,7 @@ void SKGFilePlugin::actionOpen(const KUrl & iUrl)
                                 KSharedConfigPtr config=KSharedConfig::openConfig("skrooge_filerc");
                                 KConfigGroup pref=config->group("File");
                                 pref.writePathEntry("lastfilepath",fileName);
-                        } else  err.addError(ERR_FAIL, i18n("Open of [%1] failed", fileName));
+                        } else  err.addError(ERR_FAIL, i18n("Failed to open [%1].", fileName));
 
                         //Display error
                         if (parent) parent->displayErrorMessage(err);
@@ -381,7 +392,7 @@ void SKGFilePlugin::actionChangePassword()
                 uipwd.setupUi(f);
                 d->setMainWidget( f );
                 uipwd.kPwd1->setFocus();
-                uipwd.kTitle->setPixmap(KIcon("document-encrypt").pixmap(48, 48));
+                uipwd.kTitle->setPixmap(KIcon("document-encrypt").pixmap(48, 48), KTitleWidget::ImageLeft);
                 if (d->exec()==QDialog::Accepted) {
                         QString pwd1=uipwd.kPwd1->text();
                         QString pwd2=uipwd.kPwd2->text();
@@ -392,13 +403,13 @@ void SKGFilePlugin::actionChangePassword()
                                 QApplication::restoreOverrideCursor();
 
                                 //status
-                                if (err.isSucceeded())  err=SKGError(0, i18n("password changed."));
-                                else err.addError(ERR_FAIL, i18n("Change password failed"));
+                                if (err.isSucceeded())  err=SKGError(0, i18n("Password changed."));
+                                else err.addError(ERR_FAIL, i18n("Failed to change password."));
                         } else {
                                 err=SKGError(ERR_FAIL, i18n("First and second passwords are different."));
                         }
                 } else {
-                        err=SKGError(0, i18n("Change password canceled."));
+                        err=SKGError(0, i18n("Changing password was canceled."));
                 }
                 //Display error
                 if (parent) parent->displayErrorMessage(err);
