@@ -79,7 +79,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         overlayofx.push_back("skrooge");
 
         importOfxAction = new KAction(KIcon("document-import", NULL, overlayofx), i18n("Import &OFX..."), this);
-        connect(importOfxAction, SIGNAL(triggered(bool)), SLOT(importOfx()));
+        connect(importOfxAction, SIGNAL(triggered(bool)), SLOT(import()));
         actionCollection()->addAction( QLatin1String("import_ofx"), importOfxAction );
         imports->addAction(importOfxAction);
 
@@ -90,7 +90,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
         overlaycsv.push_back("text-csv");
 
         importQifAction = new KAction(KIcon("document-import"), i18n("Import &QIF..."), this);
-        connect(importQifAction, SIGNAL(triggered(bool)), SLOT(importQif()));
+        connect(importQifAction, SIGNAL(triggered(bool)), SLOT(import()));
         actionCollection()->addAction( QLatin1String("import_qif"), importQifAction );
         imports->addAction(importQifAction);
 
@@ -98,7 +98,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
 
         //Import CSV
         importCsvAction = new KAction(KIcon("document-import", NULL, overlaycsv), i18n("Import &CSV..."), this);
-        connect(importCsvAction, SIGNAL(triggered(bool)), SLOT(importCsv()));
+        connect(importCsvAction, SIGNAL(triggered(bool)), SLOT(import()));
         actionCollection()->addAction( QLatin1String("import_csv"), importCsvAction );
         imports->addAction(importCsvAction);
 
@@ -106,7 +106,7 @@ void SKGImportExportPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDo
 
         //Import CSV Unit
         importCsvUnitAction = new KAction(KIcon("document-import", NULL, overlaycsv), i18n("Import CSV &Unit..."), this);
-        connect(importCsvUnitAction, SIGNAL(triggered(bool)), SLOT(importCsvUnit()));
+        connect(importCsvUnitAction, SIGNAL(triggered(bool)), SLOT(import()));
         actionCollection()->addAction( QLatin1String("import_csv_unit"), importCsvUnitAction );
         imports->addAction(importCsvUnitAction);
 
@@ -210,6 +210,7 @@ void SKGImportExportPlugin::refresh()
                 if (importCsvAction) importCsvAction->setEnabled(test);
                 if (exportQifAction) exportQifAction->setEnabled(test);
                 if (exportCsvAction) exportCsvAction->setEnabled(test);
+                if (importCsvUnitAction) importCsvUnitAction->setEnabled(test);
                 if (processingFoundTransfert) processingFoundTransfert->setEnabled(test);
                 if (processingBankPerfect) processingBankPerfect->setEnabled(test);
                 if (processingBank) processingBank->setEnabled(test);
@@ -221,39 +222,18 @@ void SKGImportExportPlugin::close()
         SKGTRACEIN(10, "SKGImportExportPlugin::close");
 }
 
-void SKGImportExportPlugin::importOfx()
-{
-        SKGError err;
-        SKGTRACEINRC(10, "SKGImportExportPlugin::importOfx",err);
-        import(SKGImportExportManager::OFX);
-}
-
-void SKGImportExportPlugin::importQif()
-{
-        SKGError err;
-        SKGTRACEINRC(10, "SKGImportExportPlugin::importQif",err);
-        import(SKGImportExportManager::QIF);
-}
-
-void SKGImportExportPlugin::importCsv()
-{
-        SKGError err;
-        SKGTRACEINRC(10, "SKGImportExportPlugin::importCsv",err);
-        import(SKGImportExportManager::CSV);
-}
-
-void SKGImportExportPlugin::importCsvUnit()
-{
-        SKGError err;
-        SKGTRACEINRC(10, "SKGImportExportPlugin::importCsvUnit",err);
-        import(SKGImportExportManager::CSVUNIT);
-}
-
-void SKGImportExportPlugin::import(SKGImportExportManager::ImportExportMode iMode)
+void SKGImportExportPlugin::import()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGImportExportPlugin::import",err);
         if (currentBankDocument) {
+                QAction* sender=static_cast<QAction*> ( this->sender() );
+                SKGImportExportManager::ImportExportMode iMode=SKGImportExportManager::OFX;
+
+                if (sender==importQifAction) iMode=SKGImportExportManager::QIF;
+                else if (sender==importCsvAction) iMode=SKGImportExportManager::CSV;
+                else if (sender==importCsvUnitAction) iMode=SKGImportExportManager::CSVUNIT;
+
                 QString lastCodecUsed=currentBankDocument->getParameter("SKG_LAST_CODEC_USED_FOR_IMPORT");
                 if (lastCodecUsed.length()==0) lastCodecUsed=QTextCodec::codecForLocale()->name();
 
@@ -298,8 +278,8 @@ void SKGImportExportPlugin::import(SKGImportExportManager::ImportExportMode iMod
                 }
 
                 //status bar
-                if (err.isSucceeded() && nbFiles>1) {
-                        err=SKGError(0, i18n("%1 files successfully imported.", nbFiles));
+                if (err.isSucceeded()) {
+                        err=SKGError(0, i18np("1 file successfully imported.", "%1 files successfully imported.", nbFiles));
                 }
 
                 //Display error
@@ -374,7 +354,8 @@ void SKGImportExportPlugin::foundTransfer()
                 QApplication::restoreOverrideCursor();
 
                 //status bar
-                if (err.isSucceeded()) err=SKGError(0, i18n("Document successfully processed. %1 operations merged.", NbOperationsMerged));
+                if (err.isSucceeded()) err=SKGError(0, i18np("Document successfully processed. 1 operation merged.",
+                                                            "Document successfully processed. %1 operations merged.", NbOperationsMerged));
                 else err.addError(ERR_FAIL, i18n("Processing failed."));
 
                 //Display error
