@@ -47,12 +47,11 @@ SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(SKGMainPanel* iParent, SKGDocumen
         ui.kRefresh->setIcon(KIcon("view-refresh"));
         ui.kPrint->setIcon(KIcon("printer"));
 
-        connect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()));
+        connect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(onMonthChanged()));
 
         //Refresh
-        connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(refresh()), Qt::QueuedConnection);
-
-        refresh();
+        connect((const QObject*) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)), Qt::QueuedConnection );
+        dataModified("", 0);
 }
 
 SKGMonthlyPluginWidget::~SKGMonthlyPluginWidget()
@@ -99,19 +98,20 @@ void SKGMonthlyPluginWidget::onPrint()
         if (dialog.exec() == QDialog::Accepted) {
                 QPainter painter(&printer);
                 ui.kWebView->render(&painter);
+                painter.end();
         }
 #endif
 }
 
-void SKGMonthlyPluginWidget::refresh()
+void SKGMonthlyPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-        SKGTRACEIN(1, "SKGMonthlyPluginWidget::refresh");
+        SKGTRACEIN(1, "SKGMonthlyPluginWidget::dataModified");
 
         QSqlDatabase* db = getDocument()->getDatabase();
         setEnabled(db!=NULL);
-        if (db!=NULL) {
+        if (db!=NULL &&  (iTableName=="parameters" || iTableName=="operation" || iTableName.isEmpty())) {
                 //Fill combo
-                disconnect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()));
+                disconnect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(onMonthChanged()));
 
                 QStringList list;
                 SKGServices::getDistinctValues(getDocument(), "v_operation_display", "d_DATEMONTH", "d_date<=CURRENT_DATE", list);
@@ -123,37 +123,44 @@ void SKGMonthlyPluginWidget::refresh()
                 ui.kMonth->addItems(list);
                 if (!month.isEmpty()) ui.kMonth->setText(month);
                 else if (list.count()) month=list.at(0);
-                connect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()));
+                connect(ui.kMonth, SIGNAL(currentIndexChanged(int)), this, SLOT(onMonthChanged()));
 
-                //Display report
-                QString htmlReport=getDocument()->getParameter("SKG_MONTHLY_REPORT_"+month);
-                if (htmlReport.isEmpty()) {
-                        //Report not yet generated
-                        ui.kWebView->setHtml(i18n("This monthly report is not computed yet. Click on refresh to do it !"));
-                } else {
-                        //Report generated
-                        //Set style sheet
-                        QDir dirCss(KStandardDirs::locate("data", QString::fromLatin1("skrooge/css/")));
-                        QFile file(dirCss.absoluteFilePath("skrooge_monthly-default.css"));
-                        if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
-                                return;
+                onMonthChanged();
+        }
+}
 
-                        QString style;
-                        QTextStream in(&file);
-                        while (!in.atEnd()) {
-                                style+=in.readLine();
-                        }
+void SKGMonthlyPluginWidget::onMonthChanged()
+{
+        SKGTRACEIN(1, "SKGMonthlyPluginWidget::onMonthChanged");
+        QString month=ui.kMonth->text();
 
-                        htmlReport.replace("##STYLE##", style);
+        //Display report
+        QString htmlReport=getDocument()->getParameter("SKG_MONTHLY_REPORT_"+month);
+        if (htmlReport.isEmpty()) {
+                //Report not yet generated
+                ui.kWebView->setHtml(i18n("The monthly report has not yet been computed: click on refresh to do so."));
+        } else {
+                //Report generated
+                //Set style sheet
+                QDir dirCss(KStandardDirs::locate("data", QString::fromLatin1("skrooge/css/")));
+                QFile file(dirCss.absoluteFilePath("skrooge_monthly-default.css"));
+                if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+                        return;
 
-                        //Display html report
-                        ui.kWebView->setHtml(htmlReport);
+                QString style;
+                QTextStream in(&file);
+                while (!in.atEnd()) {
+                        style+=in.readLine();
                 }
+
+                htmlReport.replace("##STYLE##", style);
+
+                //Display html report
+                ui.kWebView->setHtml(htmlReport);
         }
 }
 
 void SKGMonthlyPluginWidget::onReportRefresh()
-
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGMonthlyPluginWidget::onReportRefresh",err);
@@ -187,37 +194,40 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                 //Main title
                 html+="<h1>"+i18n("Report for %1", month)+"</h1>";
 
-                //Income & Expense
+                //Income & Expenditure
                 if (err.isSucceeded()) {
                         SKGStringListList listTmp;
                         err=SKGServices::executeSelectSqliteOrder(getDocument(),
-                                        "SELECT TOTAL(f_CURRENTAMOUNT), t_TYPEEXPENSE, d_DATEMONTH  from v_operation_display WHERE (d_DATEMONTH='"+month+"' OR d_DATEMONTH='"+previousmonth+"') AND i_group_id=0 group by d_DATEMONTH, t_TYPEEXPENSE",
+                                        "SELECT TOTAL(f_CURRENTAMOUNT), d_DATEMONTH  from v_operation_display WHERE (d_DATEMONTH='"+month+"' OR d_DATEMONTH='"+previousmonth+"') AND i_group_id=0 group by d_DATEMONTH, t_TYPEEXPENSE",
                                         listTmp);
-                        if (err.isSucceeded() && listTmp.count()>2) {
-                                html+="<h2>"+i18n("Income & Expense")+"</h2><table class=\"table\">";
+                        if (err.isSucceeded()) {
+                                html+="<h2>"+i18n("Income & Expenditure")+"</h2><table class=\"table\">";
                                 html+="<tr class=\"tabletitle\"><td align=\"center\"></td>"
                                       "<td align=\"center\">"+previousmonth+"</td>"
                                       "<td align=\"center\">"+month+"</td>"
                                       "</tr>";
                                 double income_previous_month=0;
                                 double expense_previous_month=0;
-                                double saving_previous_month=0;
-                                double income_month=SKGServices::stringToDouble(listTmp.at(1).at(0));
-                                double expense_month=SKGServices::stringToDouble(listTmp.at(2).at(0));
-                                double saving_month=income_month+expense_month;
-                                if (listTmp.count()>4) {
-                                        income_previous_month=income_month;
-                                        expense_previous_month=expense_month;
-                                        saving_previous_month=saving_month;
-                                        income_month=SKGServices::stringToDouble(listTmp.at(3).at(0));
-                                        expense_month=SKGServices::stringToDouble(listTmp.at(4).at(0));
-                                        saving_month=income_month+expense_month;
+                                double income_month=0;
+                                double expense_month=0;
+
+                                int nbval=listTmp.count();
+                                for (int i=1; i<nbval; ++i) { //Ignore header
+                                        QString m=listTmp.at(i).at(1);
+                                        double v=SKGServices::stringToDouble(listTmp.at(i).at(0));
+                                        if (v>0 && m==month) income_month=v;
+                                        else if (v<0 && m==month) expense_month=v;
+                                        else if (v>0 && m==previousmonth) income_previous_month=v;
+                                        else if (v<0 && m==previousmonth) expense_previous_month=v;
                                 }
+                                double saving_previous_month=income_previous_month+expense_previous_month;
+                                double saving_month=income_month+expense_month;
+
                                 html+=QString("<tr><td>")+i18n("Income")+"</td>"
                                       "<td align=\"right\">"+locale->formatMoney(income_previous_month, primary,2)+"</td>"
                                       "<td align=\"right\">"+locale->formatMoney(income_month, primary,2)+"</td>"
                                       "</tr>";
-                                html+=QString("<tr><td>")+i18n("Expense")+"</td>"
+                                html+=QString("<tr><td>")+i18n("Expenditure")+"</td>"
                                       "<td align=\"right\">"+locale->formatMoney(abs(expense_previous_month), primary,2)+"</td>"
                                       "<td align=\"right\">"+locale->formatMoney(abs(expense_month), primary,2)+"</td>"
                                       "</tr>";
@@ -231,7 +241,7 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                                             SKGServices::doubleToString(abs(expense_month))+','+
                                             SKGServices::doubleToString(abs(income_month))+
                                             "&chds="+range+
-                                            "&chs=300x200&chl="+i18n("Expense")+'|'+i18n("Income")+"&chtt="+i18n("Expense vs Income")+'|'+month;
+                                            "&chs=300x200&chl="+i18n("Expenditure")+'|'+i18n("Income")+"&chtt="+i18n("Expenditure vs Income")+'|'+month;
                                 // SKGTRACE << img << endl;
                                 html+="<img src=\""+img+"\" />";
                         }
@@ -244,7 +254,7 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                         SKGObjectBase::SKGListSKGObjectBase accounts;
                         SKGError err=SKGObjectBase::getObjects(getDocument(), "v_account_display", "1=1 ORDER BY t_TYPENLS", accounts);
                         if (err.isSucceeded()) {
-                                html+="<h2>"+i18n("Amount of accounts")+"</h2><table class=\"table\">";
+                                html+="<h2>"+i18n("Amounts in accounts")+"</h2><table class=\"table\">";
                                 html+="<tr class=\"tabletitle\"><td align=\"center\">"+i18n("Account")+"</td>"
                                       "<td align=\"center\">"+locale->formatDate (date1, KLocale::ShortDate)+"</td>"
                                       "<td align=\"center\">"+locale->formatDate (date2, KLocale::ShortDate)+"</td>"
@@ -341,7 +351,7 @@ void SKGMonthlyPluginWidget::onReportRefresh()
                         SKGObjectBase::SKGListSKGObjectBase units;
                         SKGError err=SKGObjectBase::getObjects(getDocument(), "v_unit_display", "1=1 ORDER BY t_TYPENLS", units);
                         if (err.isSucceeded()) {
-                                html+="<h2>"+i18n("Amount of units")+"</h2><table class=\"table\">";
+                                html+="<h2>"+i18n("Amounts of units")+"</h2><table class=\"table\">";
                                 html+="<tr class=\"tabletitle\"><td align=\"center\">"+i18n("Unit")+"</td>"
                                       "<td align=\"center\">"+locale->formatDate (date1, KLocale::ShortDate)+"</td>"
                                       "<td align=\"center\">"+locale->formatDate (date2, KLocale::ShortDate)+"</td>"
@@ -379,7 +389,7 @@ void SKGMonthlyPluginWidget::onReportRefresh()
 
         //status bar
         if (err.isSucceeded())  err=SKGError(0, i18n("Report computed."));
-        else err.addError(ERR_FAIL, i18n("Report computation failed"));
+        else err.addError(ERR_FAIL, i18n("Report computation failed."));
 
         //Display error
         getMainPanel()->displayErrorMessage(err);
