@@ -68,6 +68,12 @@ public:
          */
         virtual void refresh();
 
+        /**
+         * The dashboard widget of the plugin.
+         * @return The dashboard widget of the plugin
+         */
+        virtual SKGWidget* getDashboardWidget();
+
         /**
          * The preference widget of the plugin.
          * @return The preference widget of the plugin
@@ -138,11 +144,8 @@ public:
 
 private slots:
         void actionDuplicate();
-        void actionSwitchToChecked();
         void actionSwitchToPointed();
         void actionSwitchBookmark();
-        void actionSplitOperation();
-	//void actionSplitOperation2();
         void actionOpenBookmarks();
 
 private:
@@ -150,10 +153,8 @@ private:
 
         KAction *duplicateAction;
         KAction *switchToPointedAction;
-        KAction *switchToCheckedAction;
         KAction *switchBookmark;
         KAction *fastEditionAction;
-        KAction *splitOperationAction;
         KAction *openBookmarks;
 
         SKGMainPanel *parent;
