@@ -43,7 +43,7 @@ public:
         /**
          * Default Constructor
          */
-        SKGOperationPluginWidget(SKGMainPanel* iParent, SKGDocumentBank* iDocument, KAction* iFastEditionAction);
+        SKGOperationPluginWidget ( SKGMainPanel* iParent, SKGDocumentBank* iDocument, KAction* iFastEditionAction );
 
         /**
          * Default Destructor
@@ -75,7 +75,14 @@ public:
          * MUST BE OVERWRITTEN
          * @param iState must be interpreted to set the state of the widget
          */
-        virtual void setState(const QString& iState);
+        virtual void setState ( const QString& iState );
+
+        /**
+         * Get attribute name to save the default state
+         * MUST BE OVERWRITTEN
+         * @return attribute name to save the default state.
+         */
+        virtual QString getDefaultStateAttibute();
 
         /**
          * Get the widget must be printed
@@ -88,7 +95,7 @@ public:
          * @param iOperation the operation to open
          * @param iParent the parent widget
          */
-        static void openOperation(const SKGOperationObject& iOperation, SKGMainPanel* iParent);
+        static void openOperation ( const SKGOperationObject& iOperation, SKGMainPanel* iParent );
 
 public slots:
         /**
@@ -109,24 +116,26 @@ private slots:
         void onDoubleClick();
         void onSplitOperationClicked();
         void onQuantityChanged();
-        void onSubopCellChanged(int row,int column);
+        void onSubopCellChanged ( int row,int column );
         void onRemoveSubOperation();
         void onRefreshInformationZone();
         void onRotateAccountTools();
+        void onValidatePointedOperations();
+        void onBtnModeClicked();
 
 private:
-        Q_DISABLE_COPY(SKGOperationPluginWidget);
+        Q_DISABLE_COPY ( SKGOperationPluginWidget );
 
-        SKGError getSelectedOperation(SKGOperationObject& operation);
+        SKGError getSelectedOperation ( SKGOperationObject& operation );
 
-        void displaySplitted();
-        void displayStandard();
+        int getCurrentMode();
+        void setCurrentMode(int iMode);
         void displaySubOperations();
-        void displaySubOperations(const SKGOperationObject& iOperation);
+        void displaySubOperations ( const SKGOperationObject& iOperation );
         double getRemainingQuantity();
-        void addSubOperationLine(int row, QString category, QString comment, double quantity, int id=0);
-        SKGError updateSelection(const SKGObjectBase::SKGListSKGObjectBase& iSelection);
-
+        void addSubOperationLine ( int row, const QString& category, const QString& refund, const QString& comment, double quantity, int id=0 );
+        SKGError updateSelection ( const SKGObjectBase::SKGListSKGObjectBase& iSelection );
+        void fillNumber();
 
         Ui::skgoperationplugin_base ui;
         SKGObjectModel* objectModel;
@@ -138,9 +147,6 @@ private:
         int lastFastEditionOperationFound;
         bool showClosedAccounts;
 
-        QWidget* splittedPage;
-        QWidget* standardPage;
-
         bool numberFieldIsNotUptodate;
         int modeInfoZone;
 };
