@@ -46,6 +46,12 @@ QWidget *SKGSplitTableDelegate::createEditor(QWidget *parent,
                 SKGCalculatorEdit *editor = new SKGCalculatorEdit(parent);
                 editor->setMode(SKGCalculatorEdit::EXPRESSION);
 
+                return editor;
+        } else if (index.column() == 3) {
+                SKGComboBox *editor = new SKGComboBox(parent);
+                editor->setEditable(true);
+                if (document) SKGMainPanel::fillComboWithDistinctValue(editor, document, "refund", "t_name", "t_close='N'");
+
                 return editor;
         }
 
