@@ -20,7 +20,6 @@
  * @author Stephane MANKOWSKI
  */
 #include "skgprintplugin.h"
-#include "skgprintpluginwidget.h"
 #include "skrooge_print.h"
 #include "skgtraces.h"
 #include "skgmainpanel.h"
@@ -30,6 +29,7 @@
 
 #include <QPrinter>
 #include <QPrintDialog>
+#include <QPrintPreviewDialog>
 #include <QPainter>
 
 K_PLUGIN_FACTORY(SKGPrintPluginFactory, registerPlugin<SKGPrintPlugin>();)
@@ -45,6 +45,8 @@ SKGPrintPlugin::~SKGPrintPlugin()
         SKGTRACEIN(10, "SKGPrintPlugin::~SKGPrintPlugin");
         parent=NULL;
         currentBankDocument=NULL;
+        printAction=NULL;
+        printPreviewAction=NULL;
 }
 
 void SKGPrintPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument, const QStringList& iArgument)
@@ -58,14 +60,23 @@ void SKGPrintPlugin::setupActions(SKGMainPanel* iParent, SKGDocument* iDocument,
         setComponentData( SKGPrintPluginFactory::componentData() );
         setXMLFile("skrooge_print.rc");
 
-        KStandardAction::print(this, SLOT(actionPrint()), actionCollection());
-        //TODO KStandardAction::printPreview(this, SLOT(actionPrintPreview()), actionCollection());
+        printAction = KStandardAction::print(this, SLOT(actionPrint()), actionCollection());
+        if (parent) parent->registedGlobalAction("print", printAction);
+
+        printPreviewAction = KStandardAction::printPreview(this, SLOT(actionPrintPreview()), actionCollection());
+        if (parent) parent->registedGlobalAction("print_preview", printPreviewAction);
+
 
 }
 
 void SKGPrintPlugin::refresh()
 {
         SKGTRACEIN(10, "SKGPrintPlugin::refresh");
+        if (currentBankDocument) {
+                bool test=(currentBankDocument->getDatabase()!=NULL);
+                if (printAction) printAction->setEnabled(test);
+                if (printPreviewAction) printPreviewAction->setEnabled(test);
+        }
 }
 
 void SKGPrintPlugin::close()
@@ -76,7 +87,7 @@ void SKGPrintPlugin::close()
 SKGTabWidget* SKGPrintPlugin::getWidget()
 {
         SKGTRACEIN(10, "SKGPrintPlugin::getWidget");
-        return new SKGPrintPluginWidget(parent, currentBankDocument);
+        return NULL;
 }
 
 QWidget* SKGPrintPlugin::getPreferenceWidget()
@@ -146,48 +157,9 @@ void SKGPrintPlugin::actionPrint()
                 QPrintDialog dialog(&printer, parent);
                 if (dialog.exec() == QDialog::Accepted) {
                         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-
-                        QPainter painter;
-                        if (!painter.begin(&printer)) {
-                                err=SKGError(ERR_FAIL, i18n("Printer initialisation failed"));
-                        } else {
-                                KTabWidget* tabs=(KTabWidget*) parent->centralWidget();
-                                int nbpages=tabs->count();
-                                for (int i=0; i<nbpages; ++i) {
-                                        SKGTabWidget* page=(SKGTabWidget*) tabs->widget(i);
-                                        if (page) {
-                                                QWidget* widget=page->getWidgetForPrint();
-                                                if (widget) {
-                                                        QImage image(widget->size(), QImage::Format_ARGB32);
-                                                        QPainter painter2(&image);
-                                                        widget->render(&painter2);
-
-                                                        QRect rect = painter.viewport();
-                                                        QSize size = image.size();
-                                                        size.scale(rect.size(), Qt::KeepAspectRatio);
-                                                        painter.setViewport(rect.x(), rect.y(), size.width(), size.height());
-                                                        painter.setWindow(image.rect());
-                                                        painter.drawImage(0, 0, image);
-
-                                                        if (i<nbpages-1) {
-                                                                if (!printer.newPage()) {
-                                                                        err=SKGError(ERR_FAIL, i18n("Creation of new page failed"));
-                                                                }
-                                                        }
-                                                }
-                                        }
-                                }
-                                painter.end();
-                        }
+                        print(&printer);
                         QApplication::restoreOverrideCursor();
-
-                        //status bar
-                        if (err.isSucceeded()) err=SKGError(0, i18n("Print successfully done."));
-                        else err.addError(ERR_FAIL, i18n("Print failed"));
                 }
-
-                //Display error
-                parent->displayErrorMessage(err);
         }
 }
 
@@ -195,18 +167,56 @@ void SKGPrintPlugin::actionPrintPreview()
 {
         SKGError err;
         SKGTRACEINRC(10, "SKGPrintPlugin::actionPrintPreview",err);
-        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        /*err=currentBankDocument->save();
-        QApplication::restoreOverrideCursor();
+        QPrintPreviewDialog* preview=new QPrintPreviewDialog(parent);
+        connect(preview, SIGNAL(paintRequested(QPrinter*)), this, SLOT(print(QPrinter*)));
+        preview->exec();
+}
 
-        //Refresh
-        parent->refresh();
+void SKGPrintPlugin::print(QPrinter * iPrinter)
+{
+        if (parent && iPrinter) {
+                SKGError err;
+                QPainter painter;
+                if (!painter.begin(iPrinter)) {
+                        err=SKGError(ERR_FAIL, i18n("Printer initialisation failed"));
+                } else {
+                        KTabWidget* tabs=(KTabWidget*) parent->centralWidget();
+                        int nbpages=tabs->count();
+                        for (int i=0; i<nbpages; ++i) {
+                                SKGTabWidget* page=(SKGTabWidget*) tabs->widget(i);
+                                if (page) {
+                                        QWidget* widget=page->getWidgetForPrint();
+                                        if (widget) {
+                                                QImage image(widget->size(), QImage::Format_ARGB32);
+                                                QPainter painter2(&image);
+                                                widget->render(&painter2);
+                                                painter2.end();
 
-        //status bar
-        if (err.isSucceeded()) err=SKGError(0, i18n("File successfully saved."));
-        else err.addError(ERR_FAIL, i18n("Cannot save file"));*/
+                                                QRect rect = painter.viewport();
+                                                QSize size = image.size();
+                                                size.scale(rect.size(), Qt::KeepAspectRatio);
+                                                painter.setViewport(rect.x(), rect.y(), size.width(), size.height());
+                                                painter.setWindow(image.rect());
+                                                painter.drawImage(0, 0, image);
 
-        //Display error
-        if (parent) parent->displayErrorMessage(err);
+                                                if (i<nbpages-1) {
+                                                        if (!iPrinter->newPage()) {
+                                                                err=SKGError(ERR_FAIL, i18n("Creation of new page failed"));
+                                                        }
+                                                }
+                                        }
+                                }
+                        }
+                        painter.end();
+                }
+
+                //status bar
+                if (err.isSucceeded()) err=SKGError(0, i18n("Print successfully done."));
+                else err.addError(ERR_FAIL, i18n("Print failed"));
+
+
+                //Display error
+                parent->displayErrorMessage(err);
+        }
 }
 #include "skgprintplugin.moc"
