@@ -62,6 +62,9 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGMainPanel* iParent, SKGDocumentB
         ui.kLines->addItem(i18n("Accounts"));
         ui.kLines->addItem(i18n("Units"));
 
+        ui.kMode->addItem(i18n("Sum"));
+        ui.kMode->addItem(i18n("History"));
+
         ui.kPeriod->addItem(i18n("All dates"));
         ui.kPeriod->addItem(i18n("Current month"));
         ui.kPeriod->addItem(i18n("Previous month"));
@@ -78,16 +81,17 @@ SKGReportPluginWidget::SKGReportPluginWidget(SKGMainPanel* iParent, SKGDocumentB
 
         ui.kType->addItem(i18n("All without transfer"));
         ui.kType->addItem(i18n("Income without transfer"));
-        ui.kType->addItem(i18n("Expense without transfer"));
+        ui.kType->addItem(i18n("Expenditure without transfer"));
         ui.kType->addItem(i18n("All with transfers"));
         ui.kType->addItem(i18n("Income with transfers"));
-        ui.kType->addItem(i18n("Expense with transfers"));
+        ui.kType->addItem(i18n("Expenditure with transfers"));
 
         connect(ui.kTableWithGraph->table(), SIGNAL(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)), this, SLOT(onSelectionChanged()));
 
         //Refresh
         connect(ui.kColumns, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
         connect(ui.kLines, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
+        connect(ui.kMode, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
         connect(ui.kPeriod, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
         connect(ui.kType, SIGNAL(currentIndexChanged(int)), this, SLOT(refresh()), Qt::QueuedConnection);
         connect((const QObject*) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)));
@@ -115,6 +119,7 @@ QString SKGReportPluginWidget::getState()
 
         root.setAttribute("columns", ui.kColumns->currentIndex());
         root.setAttribute("lines", ui.kLines->currentIndex());
+        root.setAttribute("mode", ui.kMode->currentIndex());
         root.setAttribute("period", ui.kPeriod->currentIndex());
         root.setAttribute("type", ui.kType->currentIndex());
         root.setAttribute("tableAndGraphState", ui.kTableWithGraph->getState());
@@ -132,6 +137,7 @@ void SKGReportPluginWidget::setState(const QString& iState )
 
                 QString columns=root.attribute ( "columns");
                 QString lines=root.attribute ( "lines");
+                QString mode=root.attribute ( "mode");
                 QString period=root.attribute ( "period");
                 QString type=root.attribute ( "type");
                 QString tableAndGraphState=root.attribute ( "tableAndGraphState");
@@ -140,11 +146,12 @@ void SKGReportPluginWidget::setState(const QString& iState )
                 operationWhereClause=root.attribute ( "operationWhereClause");
                 if (!columns.isEmpty()) ui.kColumns->setCurrentIndex(SKGServices::stringToInt(columns));
                 if (!lines.isEmpty()) ui.kLines->setCurrentIndex(SKGServices::stringToInt(lines));
+                if (!mode.isEmpty()) ui.kMode->setCurrentIndex(SKGServices::stringToInt(mode));
                 if (!period.isEmpty()) ui.kPeriod->setCurrentIndex(SKGServices::stringToInt(period));
                 if (!type.isEmpty()) ui.kType->setCurrentIndex(SKGServices::stringToInt(type));
                 ui.kTableWithGraph->setState(tableAndGraphState);
                 if (!title.isEmpty()) {
-                        ui.kTitle->setText(title);
+                        ui.kTitle->setComment("<html><body><b>"+title+"</b></body></html>");
                         ui.kTitle->show();
                 } else {
                         ui.kTitle->hide();
@@ -158,6 +165,11 @@ void SKGReportPluginWidget::setState(const QString& iState )
         } else ui.kTableWithGraph->setState("");
 }
 
+QString SKGReportPluginWidget::getDefaultStateAttibute()
+{
+        return "SKGREPORT_DEFAULT_PARAMETERS";
+}
+
 QWidget* SKGReportPluginWidget::getWidgetForPrint()
 {
         return this;
@@ -170,9 +182,11 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
         QString title;
         if (ui.kTitle->isVisible()) oTitle=ui.kTitle->text()+'\n';
 
+        bool modeHistory=(ui.kMode->currentIndex()==1);
+
         //Condition on line attribute
         oTitle+=i18n("Operations with ");
-        if (row+1!=ui.kTableWithGraph->table()->rowCount()) {
+        if (modeHistory || row+1!=ui.kTableWithGraph->table()->rowCount()) {
                 QString att=AttsForLines[ui.kLines->currentIndex()];
                 oWc=att;
                 QString lineVal=ui.kTableWithGraph->table()->item(row, 0)->text();
@@ -189,7 +203,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
         }
         //Condition on column attribute
         int nbCol=ui.kTableWithGraph->table()->columnCount();
-        if (column!=0 && (nbCol==2 || (nbCol>=4 && column<nbCol-2))) {
+        if (modeHistory || (column!=0 && (nbCol==2 || (nbCol>=4 && column<nbCol-2)))) {
                 if (!AttsForColumns[ui.kColumns->currentIndex()].isEmpty()) {
                         if (!oWc.isEmpty()) {
                                 oWc+=" AND ";
@@ -231,13 +245,18 @@ void SKGReportPluginWidget::onDoubleClick(int row, int column)
         } else {
                 //Call operation plugin
                 QDomDocument doc("SKGML");
-                QDomElement root = doc.createElement("parameters");
-                doc.appendChild(root);
+                doc.setContent ( getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
+                QDomElement root = doc.documentElement();
+                if (root.isNull()) {
+                        root=doc.createElement("parameters");
+                        doc.appendChild(root);
+                }
+
                 root.setAttribute("operationTable", "v_operation_consolidated");
                 root.setAttribute("operationWhereClause", wc);
                 root.setAttribute("title", title);
                 root.setAttribute("title_icon", "view-statistics");
-
+                root.setAttribute ( "currentPage", "-1" );
 
                 getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
         }
@@ -255,8 +274,8 @@ void SKGReportPluginWidget::onOpenReport()
 
                 //Call report plugin
                 QDomDocument doc("SKGML");
-                QDomElement root = doc.createElement("parameters");
-                doc.appendChild(root);
+                doc.setContent(getState());
+                QDomElement root = doc.documentElement();
                 root.setAttribute("operationWhereClause", wc);
                 root.setAttribute("title", title);
                 root.setAttribute("title_icon", "view-statistics");
@@ -271,22 +290,22 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause()
         switch ( ui.kPeriod->currentIndex() ) {
         case 1:
                 //Current month
-		wc="d_DATEMONTH=STRFTIME('%Y-%m',date('now'))";
+                wc="d_DATEMONTH=STRFTIME('%Y-%m',date('now'))";
                 break;
 
         case 2:
                 //Previous month
-		wc="d_DATEMONTH=STRFTIME('%Y-%m',date('now','-1 month'))";
+                wc="d_DATEMONTH=STRFTIME('%Y-%m',date('now','-1 month'))";
                 break;
 
         case 3:
                 //Current year
-		wc="d_DATEYEAR=STRFTIME('%Y',date('now'))";
+                wc="d_DATEYEAR=STRFTIME('%Y',date('now'))";
                 break;
 
         case 4:
                 //Previous year
-		wc="d_DATEYEAR=STRFTIME('%Y',date('now','-1 year'))";
+                wc="d_DATEYEAR=STRFTIME('%Y',date('now','-1 year'))";
                 break;
         case 5:
                 //30 last days
@@ -330,7 +349,7 @@ QString SKGReportPluginWidget::getConsolidatedWhereClause()
 
         case 2:
         case 5:
-                //Expense
+                //Expenditure
                 wc+=" AND t_TYPEEXPENSE='-'";
                 break;
 
@@ -409,10 +428,38 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                                                 table.replace(0, line1);
                                         }
 
+                                        bool modeHistory=(ui.kMode->currentIndex()==1);
+                                        if (modeHistory) {
+                                                //Build history
+                                                SKGStringListList historizedTable;
+
+                                                historizedTable.push_back(table.at(0));
+
+                                                QStringList newLine;
+                                                int nblines=table.count();
+                                                int nbCols=0;
+                                                if (nblines) {
+                                                        nbCols=table.at(0).count();
+                                                }
+                                                for (int i=1; i<nblines; ++i) {
+                                                        QStringList newLine;
+                                                        newLine.push_back(table.at(i).at(0));
+
+                                                        double sum=0;
+                                                        for (int j=1; j<nbCols; ++j) {
+                                                                sum+=SKGServices::stringToDouble(table.at(i).at(j));
+                                                                newLine.push_back(SKGServices::doubleToString(sum));
+                                                        }
+                                                        historizedTable.push_back(newLine);
+                                                }
+
+                                                table=historizedTable;
+                                        }
+
                                         QString primaryUnit=((SKGDocumentBank*) getDocument())->getPrimaryUnit();
                                         QString secondaryUnit=((SKGDocumentBank*) getDocument())->getSecondaryUnit();
                                         double secondaryUnitValue=((SKGDocumentBank*) getDocument())->getSecondaryUnitValue();
-                                        ui.kTableWithGraph->setData(table, primaryUnit, secondaryUnit, secondaryUnitValue);
+                                        ui.kTableWithGraph->setData(table, primaryUnit, secondaryUnit, secondaryUnitValue, !modeHistory);
                                 }
                         }
 
