@@ -50,13 +50,8 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGMainPanel* iParent, SKGDoc
 
         connect(ui.kView->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
 
-        connect(modelview, SIGNAL(modelAboutToBeReset()), ui.kView, SLOT(saveSelection()));
-        connect(modelview, SIGNAL(modelReset()), ui.kView, SLOT(resetSelection()));
-
-        //Set view parameters
-        ui.kView->sortByColumn(0, Qt::AscendingOrder);
-        // Create the header context menu
-        ui.kView->setDefaultSaveParameters(iDocument, "SKG_DEFAULT_SCHEDULED");
+        connect(modelview, SIGNAL(beforeReset()), ui.kView, SLOT(saveSelection()));
+        connect(modelview, SIGNAL(afterReset()), ui.kView, SLOT(resetSelection()));
 
         //Add registered global action in contextual menu
         if (iParent) ui.kView->insertAction(0, iParent->getGlobalAction("edit_delete"));
@@ -65,13 +60,12 @@ SKGScheduledPluginWidget::SKGScheduledPluginWidget(SKGMainPanel* iParent, SKGDoc
         ui.kModifyBtn->setIcon(KIcon("dialog-ok-apply"));
         ui.kProcessBtn->setIcon(KIcon("system-run"));
 
-        ui.kTitle->setPixmap(KIcon("dialog-information").pixmap(22, 22));
+        ui.kTitle->setPixmap(KIcon("dialog-information").pixmap(22, 22), KTitleWidget::ImageLeft);
 
         //Refresh
-        connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(refresh()), Qt::QueuedConnection);
+        connect((const QObject*) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)), Qt::QueuedConnection );
         connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(onSelectionChanged()), Qt::QueuedConnection);
-
-        refresh();
+        dataModified("", 0);
 }
 
 SKGScheduledPluginWidget::~SKGScheduledPluginWidget()
@@ -81,25 +75,12 @@ SKGScheduledPluginWidget::~SKGScheduledPluginWidget()
 
 SKGObjectBase::SKGListSKGObjectBase SKGScheduledPluginWidget::getSelectedObjects()
 {
-        //Get Selection
-        SKGObjectBase::SKGListSKGObjectBase selection;
-        QItemSelectionModel *selModel=ui.kView->selectionModel();
-        QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kView->model();
-        SKGObjectModel* model=(SKGObjectModel*) proxyModel->sourceModel();
-        if (model) {
-                QModelIndexList indexes=selModel->selectedRows();
-                foreach(const QModelIndex& index, indexes) {
-                        SKGObjectBase obj=model->getObject(proxyModel->mapToSource(index));
-                        selection.push_back(obj);
-                }
-        }
-        return selection;
+        return ui.kView->getSelectedObjects();
 }
 
 int SKGScheduledPluginWidget::getNbSelectedObjects()
 {
-        QItemSelectionModel *selModel=ui.kView->selectionModel();
-        return (selModel ? selModel->selectedRows().count() : 0);
+        return ui.kView->getNbSelectedObjects();
 }
 
 QString SKGScheduledPluginWidget::getState()
@@ -137,18 +118,24 @@ void SKGScheduledPluginWidget::setState(const QString& iState )
         //Correction bug 2299394 ^^^
 }
 
+QString SKGScheduledPluginWidget::getDefaultStateAttibute()
+{
+        return "SKGSCHEDULED_DEFAULT_PARAMETERS";
+}
+
 QWidget* SKGScheduledPluginWidget::getWidgetForPrint()
 {
         return ui.kView;
 }
 
-void SKGScheduledPluginWidget::refresh()
+void SKGScheduledPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
 {
-        SKGTRACEIN(1, "SKGScheduledPluginWidget::refresh");
-
-        //Correction bug 2299394 vvv
-        if (ui.kView->isAutoResized()) ui.kView->resizeColumnsToContents();
-        //Correction bug 2299394 ^^^
+        SKGTRACEIN(1, "SKGScheduledPluginWidget::dataModified");
+        if (iTableName=="recurrentoperation" || iTableName.isEmpty()) {
+                //Correction bug 2299394 vvv
+                if (ui.kView->isAutoResized()) ui.kView->resizeColumnsToContents();
+                //Correction bug 2299394 ^^^
+        }
 }
 
 void SKGScheduledPluginWidget::onDoubleClick()
@@ -162,7 +149,7 @@ void SKGScheduledPluginWidget::onDoubleClick()
 
                 //Build where clause and title
                 QString wc="((SELECT count(1) FROM v_recurrentoperation s WHERE s.rd_operation_id=v_operation_consolidated.id and s.id="+SKGServices::intToString(recOp.getID())+")>0) OR r_recurrentoperation_id="+SKGServices::intToString(recOp.getID());
-                QString title=i18n("Operations recurrent");
+                QString title=i18n("Recurrent operations");
 
                 //Open
                 if (QApplication::keyboardModifiers()&Qt::ControlModifier && QApplication::keyboardModifiers()&Qt::ShiftModifier) {
@@ -176,12 +163,18 @@ void SKGScheduledPluginWidget::onDoubleClick()
                 } else {
                         //Call operation plugin
                         QDomDocument doc("SKGML");
-                        QDomElement root = doc.createElement("parameters");
-                        doc.appendChild(root);
+                        doc.setContent ( getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
+                        QDomElement root = doc.documentElement();
+                        if (root.isNull()) {
+                                root=doc.createElement("parameters");
+                                doc.appendChild(root);
+                        }
+
                         root.setAttribute("operationTable", "v_operation_consolidated");
                         root.setAttribute("operationWhereClause", wc);
                         root.setAttribute("title", title);
                         root.setAttribute("title_icon", "view-statistics");
+                        root.setAttribute ( "currentPage", "-1" );
 
                         getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
                 }
