@@ -77,35 +77,8 @@ void SKGUnitPlugin::close()
 void SKGUnitPlugin::refresh()
 {
         SKGTRACEIN(10, "SKGUnitPlugin::refresh");
-        //Automatic download
-        if (parent && currentBankDocument && currentBankDocument->getDatabase()!=NULL) {
-                QString doc_id=currentBankDocument->getParameter("SKG_UNIQUE_ID");
-                if (docUniqueIdentifier!=doc_id) {
-                        docUniqueIdentifier=doc_id;
-
-                        //Read Setting
-                        KSharedConfigPtr config=KSharedConfig::openConfig("skrooge_unitrc");
-                        KConfigGroup pref=config->group("skrooge_unit");
-                        bool download_on_open = pref.readEntry("download_on_open",false);
-                        if (download_on_open) {
-                                SKGError err;
-                                QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-
-                                //download all units
-                                SKGObjectBase::SKGListSKGObjectBase selection;
-                                err=SKGObjectBase::getObjects(currentBankDocument, "unit","", selection);
-                                int nb=selection.count();
-                                for (int i=0; err.isSucceeded() && i<nb; ++i) {
-                                        SKGUnitObject unit=selection.at(i);
-                                        err=SKGUnitPluginWidget::downloadUnitValue(unit, parent);
-                                }
-                                QApplication::restoreOverrideCursor();
-
-                                //Display error
-                                parent->displayErrorMessage(err);
-                        }
-                }
-
+        if (parent && currentBankDocument) {
+                bool test=(currentBankDocument->getDatabase()!=NULL);
                 if (splitShareAction) {
                         SKGObjectBase::SKGListSKGObjectBase selection=parent->getSelectedObjects();
                         if (selection.count()==1 && selection.at(0).getRealTable()=="unit") {
@@ -115,6 +88,36 @@ void SKGUnitPlugin::refresh()
                                 splitShareAction->setEnabled(false);
                         }
                 }
+
+                //Automatic download
+                if (test) {
+                        QString doc_id=currentBankDocument->getUniqueIdentifier();
+                        if (docUniqueIdentifier!=doc_id) {
+                                docUniqueIdentifier=doc_id;
+
+                                //Read Setting
+                                KSharedConfigPtr config=KSharedConfig::openConfig("skrooge_unitrc");
+                                KConfigGroup pref=config->group("skrooge_unit");
+                                bool download_on_open = pref.readEntry("download_on_open",false);
+                                if (download_on_open) {
+                                        SKGError err;
+                                        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+
+                                        //download all units
+                                        SKGObjectBase::SKGListSKGObjectBase selection;
+                                        err=SKGObjectBase::getObjects(currentBankDocument, "unit","", selection);
+                                        int nb=selection.count();
+                                        for (int i=0; err.isSucceeded() && i<nb; ++i) {
+                                                SKGUnitObject unit=selection.at(i);
+                                                err=SKGUnitPluginWidget::downloadUnitValue(unit, parent);
+                                        }
+                                        QApplication::restoreOverrideCursor();
+
+                                        //Display error
+                                        parent->displayErrorMessage(err);
+                                }
+                        }
+                }
         }
 }
 
@@ -150,7 +153,7 @@ QString SKGUnitPlugin::icon() const
 
 QString SKGUnitPlugin::statusTip () const
 {
-        return i18n("Unit management (creation, update ...)");
+        return i18n("Unit management (creation, update, ...)");
 }
 
 QString SKGUnitPlugin::toolTip () const
@@ -190,10 +193,10 @@ void SKGUnitPlugin::actionSplitShare()
                         bool ok=false;
                         double ratio=KInputDialog::getDouble  (i18n("Split share"),
                                                                i18n("Ratio (2 means 2-for-1, 0.5 means 1-for-2) :"), 2.0,
-                                                               0, DBL_MAX, 2, &ok, parent);
+                                                               0, DBL_MAX, 8, &ok, parent);
                         if (ok) {
                                 SKGUnitObject unit=selection.at(0);
-                                SKGBEGINTRANSACTION(*currentBankDocument, i18n("Split strock [%1] by [%2]", unit.getName(), ratio), err);
+                                SKGBEGINTRANSACTION(*currentBankDocument, i18n("Split stock [%1] by [%2]", unit.getName(), ratio), err);
                                 QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
                                 err=unit.split(ratio);
                                 QApplication::restoreOverrideCursor();
@@ -201,8 +204,8 @@ void SKGUnitPlugin::actionSplitShare()
                 }
 
                 //status
-                if (err.isSucceeded())  err=SKGError(0, i18n("Strock splitted."));
-                else err.addError(ERR_FAIL, i18n("Split strock failed"));
+                if (err.isSucceeded())  err=SKGError(0, i18n("Stock split."));
+                else err.addError(ERR_FAIL, i18n("Splitting stock failed."));
 
                 //Display error
                 parent->displayErrorMessage(err);
