@@ -47,11 +47,14 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
         ui.setupUi(this);
         //Add Standard KDE Icons to buttons to Accounts
         ui.kUnitAdd->setIcon(KIcon("list-add"));
-        ui.kCurrencyAdd->setIcon(KIcon("list-add"));
         ui.kUnitUpdate->setIcon(KIcon("dialog-ok-apply"));
-        ui.kUnitValueAdd->setIcon(KIcon("list-add"));
         ui.kUnitValueDownload->setIcon(KIcon("network-workgroup"));
 
+        ui.kStandardBtn->setIcon (KIcon ( "dialog-ok-apply" ) );
+        ui.kManualBtn->setIcon (KIcon ( "user-properties" ) );
+        ui.kValuesBtn->setIcon (KIcon ( "skrooge_unit" ) );
+
+
         //Fill combo box for type
         ui.kTypeCreatorUnit->addItem(i18n("Primary currency"));
         ui.kTypeCreatorUnit->addItem(i18n("Secondary currency"));
@@ -75,9 +78,6 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
                 ui.kUnitTableViewEdition->setModel(modelProxy);
                 ui.kUnitTableViewEdition->setWindowTitle(i18n("Units"));
 
-                // Create the header context menu
-                ui.kUnitTableViewEdition->setDefaultSaveParameters(getDocument(), "SKG_DEFAULT_UNIT");
-
                 //Add registered global action in contextual menu
                 if (iParent) {
                         ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_delete"));
@@ -88,11 +88,9 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
                         ui.kUnitTableViewEdition->insertAction(0, sep);
                         ui.kUnitTableViewEdition->insertAction(0, iParent->getGlobalAction("open_report"));
                 }
-                connect(ui.kUnitTableViewEdition->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
-                        this, SLOT(onSelectionChanged()));
-
-                connect(objectModel, SIGNAL(modelAboutToBeReset()), ui.kUnitTableViewEdition, SLOT(saveSelection()));
-                connect(objectModel, SIGNAL(modelReset()), ui.kUnitTableViewEdition, SLOT(resetSelection()));
+                connect(ui.kUnitTableViewEdition->selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SLOT(onSelectionChanged()));
+                connect(objectModel, SIGNAL(beforeReset()), ui.kUnitTableViewEdition, SLOT(saveSelection()));
+                connect(objectModel, SIGNAL(afterReset()), ui.kUnitTableViewEdition, SLOT(resetSelection()));
         }
 
         //Bind unit creation view
@@ -102,9 +100,6 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
                 ui.kUnitValueTableViewEdition->setModel(objectModel2);
                 ui.kUnitValueTableViewEdition->setWindowTitle(i18n("Unit values"));
 
-                // Create the header context menu
-                ui.kUnitValueTableViewEdition->setDefaultSaveParameters(getDocument(), "SKG_DEFAULT_UNITVALUE");
-
                 //Add registered global action in contextual menu
                 if (iParent) ui.kUnitValueTableViewEdition->insertAction(0, iParent->getGlobalAction("edit_delete"));
 
@@ -112,12 +107,11 @@ SKGUnitPluginWidget::SKGUnitPluginWidget(SKGMainPanel* iParent, SKGDocumentBank*
                         this, SLOT(onSelectionValueChanged()));
         }
 
-        ui.kUnitTableViewEdition->sortByColumn(0, Qt::AscendingOrder);
-
         //Refresh
-        connect((const QObject*) getDocument(), SIGNAL(transactionSuccessfullyEnded(int)), this, SLOT(refresh()), Qt::QueuedConnection);
+        connect((const QObject*) getDocument(), SIGNAL(tableModified(QString, int)), this, SLOT(dataModified(QString, int)), Qt::QueuedConnection );
+        dataModified("", 0);
 
-        refresh();
+        setCurrentMode(0);
 }
 
 SKGUnitPluginWidget::~SKGUnitPluginWidget()
@@ -243,6 +237,54 @@ void SKGUnitPluginWidget::onSelectionValueChanged()
         }
 }
 
+int SKGUnitPluginWidget::getCurrentMode()
+{
+        if (ui.kStandardFrm->isVisible()) return 0;
+        else if (ui.kManualFrm->isVisible()) return 1;
+        else if (ui.kValuesFrm->isVisible()) return 2;
+        return -1;
+}
+
+void SKGUnitPluginWidget::onBtnModeClicked()
+{
+        QWidget* sender=static_cast<QWidget*> ( this->sender() );
+
+        int currentMode=getCurrentMode();
+        int newMode=0;
+
+        if (sender==ui.kStandardBtn) newMode=0;
+        else if (sender==ui.kManualBtn) newMode=1;
+        else if (sender==ui.kValuesBtn) newMode=2;
+
+        if (currentMode==newMode) newMode=-1;
+        setCurrentMode(newMode);
+}
+
+void SKGUnitPluginWidget::setCurrentMode(int iMode)
+{
+        ui.kStandardFrm->hide();
+        ui.kManualFrm->hide();
+        ui.kValuesFrm->hide();
+
+        ui.kStandardBtn->setChecked(false);
+        ui.kManualBtn->setChecked(false);
+        ui.kValuesBtn->setChecked(false);
+        ui.kBtnFrm->setVisible(iMode>=0);
+
+        if (iMode==0) {
+                ui.kStandardFrm->show();
+                ui.kStandardBtn->setChecked(true);
+        } else if (iMode==1) {
+                ui.kManualFrm->show();
+                ui.kManualBtn->setChecked(true);
+        } else if (iMode==2) {
+                ui.kValuesFrm->show();
+                ui.kValuesBtn->setChecked(true);
+        }
+
+        onUnitCreatorModified();
+}
+
 void SKGUnitPluginWidget::onUnitCreatorModified()
 {
         SKGTRACEIN(10, "SKGUnitPluginWidget::onUnitCreatorModified");
@@ -252,10 +294,11 @@ void SKGUnitPluginWidget::onUnitCreatorModified()
 
         int nbSelect=getNbSelectedObjects();
 
-        ui.kUnitAdd->setEnabled(activated);
-        ui.kUnitUpdate->setEnabled(activated && nbSelect>0);
+        ui.kUnitAdd->setEnabled(activated || getCurrentMode()==0);
+        ui.kUnitUpdate->setEnabled(activated && nbSelect>0 && getCurrentMode()==1);
 
-        ui.kUnitValueAdd->setEnabled(activated && nbSelect>0);
+        ui.kValuesBtn->setEnabled(activated && nbSelect==1);
+        if (!(activated && nbSelect>0) && getCurrentMode()==2) setCurrentMode(0);
 }
 
 void SKGUnitPluginWidget::onAddUnit()
@@ -263,7 +306,14 @@ void SKGUnitPluginWidget::onAddUnit()
         SKGError err;
         SKGTRACEINRC(10, "SKGUnitPluginWidget::onAddUnit",err);
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        {
+        int mode=getCurrentMode();
+
+        if (mode==0) {
+                QString untiname=ui.kCurrencyList->text();
+                SKGBEGINTRANSACTION(*getDocument(), i18n("Unit creation [%1]", untiname), err);
+                SKGUnitObject oUnit;
+                err=SKGUnitObject::createCurrencyUnit((SKGDocumentBank*) getDocument(), ui.kCurrencyList->text(), oUnit);
+        } else if (mode==1) {
                 QString untiname=ui.kNameCreatorUnit->text();
                 SKGUnitObject unitObj(getDocument());
                 {
@@ -290,6 +340,18 @@ void SKGUnitPluginWidget::onAddUnit()
                         err=SKGError(0, i18n("Unit [%1] created", untiname));
                         ui.kUnitTableViewEdition->selectObject(unitObj.getUniqueID());
                 } else err.addError(ERR_FAIL, i18n("Unit creation failed"));
+        } else if (mode==2) {
+                QString untiname=ui.kNameCreatorUnit->text();
+                SKGUnitValueObject unitValueObject;
+                {
+                        SKGBEGINTRANSACTION(*getDocument(), i18n("Unit value creation for [%1]", untiname), err);
+                        err=((SKGDocumentBank*) getDocument())->addOrModifyUnitValue(untiname, ui.kDateEdit->date(), ui.kAmountEdit->value(), &unitValueObject);
+                }
+                //status bar
+                if (err.isSucceeded()) {
+                        err=SKGError(0, i18n("Unit value created for [%1]", untiname));
+                        //TODO doesn't work because of unit table is modified an refreshed ui.kUnitValueTableViewEdition->selectObject(unitValueObject.getUniqueID());
+                } else err.addError(ERR_FAIL, i18n("Unit value creation failed"));
         }
         QApplication::restoreOverrideCursor();
 
@@ -297,21 +359,6 @@ void SKGUnitPluginWidget::onAddUnit()
         getMainPanel()->displayErrorMessage(err);
 }
 
-void SKGUnitPluginWidget::onAddCurrency()
-{
-        SKGError err;
-        SKGTRACEINRC(10, "SKGUnitPluginWidget::onAddCurrency",err);
-        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        QApplication::restoreOverrideCursor();
-        {
-                QString untiname=ui.kCurrencyList->text();
-                SKGBEGINTRANSACTION(*getDocument(), i18n("Unit creation [%1]", untiname), err);
-                SKGUnitObject oUnit;
-                err=SKGUnitObject::createCurrencyUnit((SKGDocumentBank*) getDocument(), ui.kCurrencyList->text(), oUnit);
-        }
-        //Display error
-        getMainPanel()->displayErrorMessage(err);
-}
 
 
 void SKGUnitPluginWidget::onModifyUnit()
@@ -324,7 +371,7 @@ void SKGUnitPluginWidget::onModifyUnit()
 
         int nb=selection.count();
         if (nb) {
-                SKGBEGINPROGRESSTRANSACTION(*getDocument(), (nb==1 ? i18n("Unit [%1] update", ui.kNameCreatorUnit->text()) : i18n("%1 units update.", nb))  , err, nb);
+                SKGBEGINPROGRESSTRANSACTION(*getDocument(), (nb==1 ? i18n("Unit [%1] update", ui.kNameCreatorUnit->text()) : i18n("Updating %1 units.", nb))  , err, nb);
 
                 for (int i=0; err.isSucceeded() && i<nb; i++) {
                         //Modification of unit object
@@ -358,30 +405,6 @@ void SKGUnitPluginWidget::onModifyUnit()
         getMainPanel()->displayErrorMessage(err);
 }
 
-void SKGUnitPluginWidget::onAddUnitValue()
-{
-        SKGError err;
-        SKGTRACEINRC(10, "SKGUnitPluginWidget::onAddUnitValue",err);
-        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        {
-                QString untiname=ui.kNameCreatorUnit->text();
-                SKGUnitValueObject unitValueObject;
-                {
-                        SKGBEGINTRANSACTION(*getDocument(), i18n("Unit value creation for [%1]", untiname), err);
-                        err=((SKGDocumentBank*) getDocument())->addOrModifyUnitValue(untiname, ui.kDateEdit->date(), ui.kAmountEdit->value(), &unitValueObject);
-                }
-                //status bar
-                if (err.isSucceeded()) {
-                        err=SKGError(0, i18n("Unit value created for [%1]", untiname));
-                        //TODO doesn't work because of unit table is modified an refreshed ui.kUnitValueTableViewEdition->selectObject(unitValueObject.getUniqueID());
-                } else err.addError(ERR_FAIL, i18n("Unit value creation failed"));
-        }
-        QApplication::restoreOverrideCursor();
-
-        //Display error
-        getMainPanel()->displayErrorMessage(err);
-}
-
 void SKGUnitPluginWidget::onDoubleClickUnit()
 {
         _SKGTRACEIN(10, "SKGUnitPluginWidget::onDoubleClick");
@@ -408,13 +431,18 @@ void SKGUnitPluginWidget::onDoubleClickUnit()
                 } else {
                         //Call operation plugin
                         QDomDocument doc("SKGML");
-                        QDomElement root = doc.createElement("parameters");
-                        doc.appendChild(root);
+                        doc.setContent ( getDocument()->getParameter("SKGOPERATION_DEFAULT_PARAMETERS") );
+                        QDomElement root = doc.documentElement();
+                        if (root.isNull()) {
+                                root=doc.createElement("parameters");
+                                doc.appendChild(root);
+                        }
+
                         root.setAttribute("operationTable", "v_operation_consolidated");
                         root.setAttribute("operationWhereClause", wc);
                         root.setAttribute("title", title);
                         root.setAttribute("title_icon", "view-statistics");
-
+                        root.setAttribute ( "currentPage", "-1" );
 
                         getMainPanel()->setNewTabContent(getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
                 }
@@ -503,7 +531,7 @@ SKGError SKGUnitPluginWidget::downloadUnitValue(const SKGUnitObject& iUnit, QWid
                                         stream.readLine(); //to forget column names
 
                                         int nbLoaded=0;
-                                        while (!stream.atEnd() && err.isSucceeded() && nbLoaded<=50) { //TODO set nbLoaded as parameters
+                                        while (!stream.atEnd() && err.isSucceeded() && nbLoaded<pref.readEntry("nb_loaded_values", 50)-1) {//-1 because the value of the day will be loaded after
                                                 //Read line
                                                 QString line=stream.readLine().trimmed();
                                                 QStringList fields=SKGServices::splitCSVLine(line, ',');
@@ -621,41 +649,18 @@ void SKGUnitPluginWidget::onDownloadUnitValue()
 
 SKGObjectBase::SKGListSKGObjectBase SKGUnitPluginWidget::getSelectedObjects()
 {
-        //Get Selection
-        SKGObjectBase::SKGListSKGObjectBase selection;
         if (ui.kUnitValueTableViewEdition->hasFocus()) {
-                //Selection on unit values
-                QItemSelectionModel *selModel=ui.kUnitValueTableViewEdition->selectionModel();
-                SKGObjectModel* model=(SKGObjectModel*) ui.kUnitValueTableViewEdition->model();
-                if (model && selModel) {
-                        QModelIndexList indexes=selModel->selectedRows();
-                        foreach(const QModelIndex& index, indexes) {
-                                SKGObjectBase obj=model->getObject(index);
-                                selection.push_back(obj);
-                        }
-                }
-        } else {
-                //Selection on units
-                QItemSelectionModel *selModel=ui.kUnitTableViewEdition->selectionModel();
-                QSortFilterProxyModel* proxyModel=(QSortFilterProxyModel*) ui.kUnitTableViewEdition->model();
-                SKGObjectModel* model=(SKGObjectModel*) proxyModel->sourceModel();
-                if (model) {
-                        QModelIndexList indexes=selModel->selectedRows();
-                        foreach(const QModelIndex& index, indexes) {
-                                SKGObjectBase obj=model->getObject(proxyModel->mapToSource(index));
-                                selection.push_back(obj);
-                        }
-                }
+                return ui.kUnitValueTableViewEdition->getSelectedObjects();
         }
-        return selection;
+        return ui.kUnitTableViewEdition->getSelectedObjects();
 }
 
 int SKGUnitPluginWidget::getNbSelectedObjects()
 {
         if (ui.kUnitValueTableViewEdition->hasFocus()) {
-                return ui.kUnitValueTableViewEdition->selectionModel()->selectedRows().count();
+                return ui.kUnitValueTableViewEdition->getNbSelectedObjects();
         }
-        return ui.kUnitTableViewEdition->selectionModel()->selectedRows().count();
+        return ui.kUnitTableViewEdition->getNbSelectedObjects();
 }
 
 
@@ -666,12 +671,13 @@ QString SKGUnitPluginWidget::getState()
         QDomElement root = doc.createElement("parameters");
         doc.appendChild(root);
 
-        root.setAttribute("splitter1State", QString(ui.splitter->saveState().toHex()));
-        root.setAttribute("splitter2State", QString(ui.splitter_2->saveState().toHex()));
+        root.setAttribute("splitter1State", QString(ui.kMainSplitter->saveState().toHex()));
+        root.setAttribute("splitter2State", QString(ui.kValuesSplitter->saveState().toHex()));
 
         //Memorize table settings
         root.setAttribute("unitview", ui.kUnitTableViewEdition->getState());
         root.setAttribute("unitvalueview", ui.kUnitValueTableViewEdition->getState());
+        root.setAttribute ( "currentPage", getCurrentMode() );
 
         return doc.toString();
 }
@@ -684,9 +690,11 @@ void SKGUnitPluginWidget::setState(const QString& iState )
         QDomElement root = doc.documentElement();
 
         QString splitter1State=root.attribute ( "splitter1State");
-        if (!splitter1State.isEmpty()) ui.splitter->restoreState(QByteArray::fromHex(splitter1State.toAscii()));
+        if (!splitter1State.isEmpty()) ui.kMainSplitter->restoreState(QByteArray::fromHex(splitter1State.toAscii()));
         QString splitter2State=root.attribute ( "splitter2State");
-        if (!splitter2State.isEmpty()) ui.splitter_2->restoreState(QByteArray::fromHex(splitter2State.toAscii()));
+        if (!splitter2State.isEmpty()) ui.kValuesSplitter->restoreState(QByteArray::fromHex(splitter2State.toAscii()));
+        QString currentPage=root.attribute ( "currentPage" );
+        if ( !currentPage.isEmpty() ) setCurrentMode ( SKGServices::stringToInt ( currentPage ) );
 
         ui.kUnitTableViewEdition->setState(root.attribute ( "unitview"));
         ui.kUnitValueTableViewEdition->setState(root.attribute ( "unitvalueview"));
@@ -700,26 +708,32 @@ void SKGUnitPluginWidget::setState(const QString& iState )
         }
 }
 
-void SKGUnitPluginWidget::refresh()
+QString SKGUnitPluginWidget::getDefaultStateAttibute()
 {
-        SKGTRACEIN(10, "SKGUnitPluginWidget::refresh");
+        return "SKGUNIT_DEFAULT_PARAMETERS";
+}
 
-        //Refresh widgets
-        setEnabled(getDocument()->getDatabase()!=NULL);
+void SKGUnitPluginWidget::dataModified(const QString& iTableName, int iIdTransaction)
+{
+        SKGTRACEIN(10, "SKGUnitPluginWidget::dataModified");
+        if (iTableName=="unit" || iTableName.isEmpty()) {
+                //Refresh widgets
+                setEnabled(getDocument()->getDatabase()!=NULL);
 
-        //Correction bug 2299394 vvv
-        if (ui.kUnitTableViewEdition->isAutoResized())ui.kUnitTableViewEdition->resizeColumnsToContents();
-        if (ui.kUnitValueTableViewEdition->isAutoResized()) ui.kUnitValueTableViewEdition->resizeColumnsToContents();
-        //Correction bug 2299394 ^^^
+                //Correction bug 2299394 vvv
+                if (ui.kUnitTableViewEdition->isAutoResized())ui.kUnitTableViewEdition->resizeColumnsToContents();
+                if (ui.kUnitValueTableViewEdition->isAutoResized()) ui.kUnitValueTableViewEdition->resizeColumnsToContents();
+                //Correction bug 2299394 ^^^
 
-        QStringList list;
-        SKGServices::getDistinctValues(getDocument(), "unit", "ifnull(t_symbol,t_name)", "t_type IN ('1','2','C')", list);
+                QStringList list;
+                SKGServices::getDistinctValues(getDocument(), "unit", "ifnull(t_symbol,t_name)", "t_type IN ('1','2','C')", list);
 
-        //Fill combo
-        ui.kUnitCreatorUnit->clear();
-        list.insert(0, "");
-        ui.kUnitCreatorUnit->addItems(list);
+                //Fill combo
+                ui.kUnitCreatorUnit->clear();
+                list.insert(0, "");
+                ui.kUnitCreatorUnit->addItems(list);
 
-        onSelectionChanged();
+                onSelectionChanged();
+        }
 }
 #include "skgunitpluginwidget.moc"
